# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/downloader.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Initializer(object):
    def setupUi(self, Initializer):
        Initializer.setObjectName("Initializer")
        Initializer.resize(222, 320)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Initializer.setWindowIcon(icon)
        self.widget = QtWidgets.QWidget(Initializer)
        self.widget.setGeometry(QtCore.QRect(0, 0, 221, 311))
        self.widget.setObjectName("widget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.widget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_2 = QtWidgets.QLabel(self.widget)
        self.label_2.setText("")
        self.label_2.setTextFormat(QtCore.Qt.PlainText)
        self.label_2.setPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"))
        self.label_2.setScaledContents(True)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setWordWrap(True)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.stat = QtWidgets.QLabel(self.widget)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(30)
        font.setBold(True)
        font.setWeight(75)
        self.stat.setFont(font)
        self.stat.setScaledContents(False)
        self.stat.setAlignment(QtCore.Qt.AlignCenter)
        self.stat.setObjectName("stat")
        self.verticalLayout.addWidget(self.stat)
        self.label_3 = QtWidgets.QLabel(self.widget)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.verticalLayout.addWidget(self.label_3)

        self.retranslateUi(Initializer)
        QtCore.QMetaObject.connectSlotsByName(Initializer)

    def retranslateUi(self, Initializer):
        _translate = QtCore.QCoreApplication.translate
        Initializer.setWindowTitle(_translate("Initializer", "Initializing"))
        self.stat.setText(_translate("Initializer", "guiscrcpy"))
        self.label_3.setText(_translate("Initializer", "Initializing"))
from . import rsrc_rc



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import logging
import uuid

from qtpy import QtGui, QtWidgets, QtCore
from qtpy.QtCore import Qt, QPoint
from qtpy.QtWidgets import QMainWindow

from guiscrcpy.lib.toolkit import UXMapper


class SwipeUX(QMainWindow):
    def __init__(self, ux_wrapper=None, frame=False, always_on_top=True):
        """
        Swipe UI
        :param ux_wrapper: UXMapper type object
        :param frame: bool
        :param always_on_top: bool
        """
        QMainWindow.__init__(self)
        self.oldPos = None
        self.name = "swipe"
        self.uid = uuid.uuid4()

        # =================
        if ux_wrapper:
            self.ux = ux_wrapper
        else:
            self.ux = UXMapper()
        hexdigest = self.ux.get_sha()[:6]

        self.setObjectName("SwipeUX")
        __flags = QtCore.Qt.Window
        if not frame:
            __flags |= QtCore.Qt.FramelessWindowHint
            self.setAttribute(Qt.WA_NoSystemBackground, True)
            self.setAttribute(Qt.WA_TranslucentBackground, True)
        if always_on_top:
            __flags |= QtCore.Qt.WindowStaysOnTopHint
        self.setWindowFlags(__flags)

        # self.setWindowFlags(QtCore.Qt.WindowStaysOnTopHint
        # QtCore.Qt.FramelessWindowHint)
        self.resize(70, 70)
        # -----------------------

        icon = QtGui.QIcon()
        icon.addPixmap(
            QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.Off,
        )
        self.setWindowIcon(icon)
        self.setStyleSheet(
            "QWidget {"
            "background-color: rgba(0,0,0,0);}\nQPushButton {\n"
            "border-radius: 15px;\n"
            "background-color: qradialgradient("
            "spread:pad, cx:0.5, cy:0.5, radius:0.5, fx:0.495098, fy:0.5, "
            "stop:0.887255 rgba(35, 35, 35, 255), "
            "stop:0.901961 rgba(0, 0, 0, 255));\n"
            "color: rgb(0, 0, 0);\n"
            "}\n\n"
            "QPushButton:pressed {\n"
            "border-radius: 15px;\n"
            "\n"
            "background-color: qlineargradient("
            "spread:pad, x1:0, y1:0, x2:1, y2:1, "
            "stop:0 rgba(0, 255, 255, 255), "
            "stop:1 rgba(0, 255, 152, 255));\n"
            "color: rgb(0, 0, 0);\n"
            "   }\n"
            "QMainWindow{background-color: rgba(0,0,0,30);}\n"
            "QPushButton:hover {\n"
            "border-radius: 15px;\n"
            "background-color: qlineargradient("
            "spread:pad, x1:0, y1:0, x2:1, y2:1, "
            "stop:0 rgba(0, 199, 199, 255), "
            "stop:1 rgba(0, 190, 113, 255));\n"
            "color: rgb(0, 0, 0);\n"
            "}"
        )
        self.centralwidget = QtWidgets.QWidget(self)
        self.centralwidget.setObjectName("centralwidget")

        self.lol = QtWidgets.QPushButton(self.centralwidget)
        self.lol.setGeometry(QtCore.QRect(24, 24, 25, 25))
        self.lol.setText("")
        self.lol.setObjectName("lol")
        self.lol.setStyleSheet(
            f"background-color: #{hexdigest};" f"border-radius: 12px; "
        )
        self.swirt = QtWidgets.QPushButton(self.centralwidget)
        self.swirt.setGeometry(QtCore.QRect(40, 20, 30, 30))
        self.swirt.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(
            QtGui.QPixmap(":/icons/icons/chevron-sign-right.svg"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.Off,
        )
        self.swirt.setIcon(icon1)
        self.swirt.setObjectName("swirt")
        self.swilf = QtWidgets.QPushButton(self.centralwidget)
        self.swilf.setGeometry(QtCore.QRect(0, 20, 30, 30))
        self.swilf.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(
            QtGui.QPixmap(":/icons/icons/chevron-sign-left.svg"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.Off,
        )
        self.swilf.setIcon(icon2)
        self.swilf.setObjectName("swilf")
        self.swidn = QtWidgets.QPushButton(self.centralwidget)
        self.swidn.setGeometry(QtCore.QRect(20, 40, 30, 30))
        self.swidn.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(
            QtGui.QPixmap(":/icons/icons/chevron-sign-down.svg"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.Off,
        )
        self.swidn.setIcon(icon3)
        self.swidn.setObjectName("swidn")
        self.swiup = QtWidgets.QPushButton(self.centralwidget)
        self.swiup.setGeometry(QtCore.QRect(20, 0, 30, 30))
        self.swiup.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(
            QtGui.QPixmap(":/icons/icons/chevron-sign-up.svg"),
            QtGui.QIcon.Normal,
            QtGui.QIcon.Off,
        )
        self.swiup.setIcon(icon4)
        self.swiup.setObjectName("swiup")
        self.setCentralWidget(self.centralwidget)
        self.oldpos = self.pos()
        self.swiup.pressed.connect(self.swipup)
        self.swidn.pressed.connect(self.swipdn)
        self.swilf.pressed.connect(self.swipleft)
        self.swirt.pressed.connect(self.swipright)

    def init(self):
        self.show()

    def paintEvent(self, event):
        qp = QtGui.QPainter()
        qp.begin(self)
        qp.setRenderHint(QtGui.QPainter.Antialiasing)
        qp.setPen(Qt.NoPen)
        qp.setBrush(QtGui.QColor(0, 0, 0, 127))
        qp.drawEllipse(0, 0, 70, 70)
        qp.end()

    def mousePressEvent(self, event):
        self.oldPos = event.globalPos()

    def mouseMoveEvent(self, event):
        try:
            delta = QPoint(event.globalPos() - self.oldPos)

            self.move(self.x() + delta.x(), self.y() + delta.y())
            self.oldPos = event.globalPos()
        except (TypeError, AttributeError):
            pass

    def swipdn(self):
        logging.debug("Passing SWIPE DOWN")
        dim_values = self.ux.android_dimensions
        pos_y = int(dim_values[1]) - 200
        pos_x = int(dim_values[0])
        new_pos_x = pos_x / 2  # find center
        self.ux.do_swipe(new_pos_x, 200, new_pos_x, pos_y)

    def swipup(self):
        logging.debug("Passing SWIPE UP")
        dim_values = self.ux.android_dimensions
        pos_y = int(dim_values[1]) - 100
        pos_x = int(dim_values[0])
        new_pos_x = int(pos_x / 2)  # find center
        self.ux.do_swipe(new_pos_x, pos_y, new_pos_x, 200)

    def swipleft(self):
        logging.debug("Passing SWIPE LEFT")
        dim_values = self.ux.android_dimensions
        pos_y = int(dim_values[1])
        pos_x = int(dim_values[0]) - 10
        new_pos_y = int(pos_y / 2)  # find center
        self.ux.do_swipe(10, new_pos_y, pos_x, new_pos_y)

    def swipright(self):
        logging.debug("Passing SWIPE RIGHT")
        dim_values = self.ux.android_dimensions
        pos_y = int(dim_values[1])
        pos_x = int(dim_values[0]) - 10
        new_pos_y = int(pos_y / 2)  # find center
        self.ux.do_swipe(pos_x, new_pos_y, 10, new_pos_y)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/toolkit_ui.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ToolbarPanel(object):
    def setupUi(self, ToolbarPanel):
        ToolbarPanel.setObjectName("ToolbarPanel")
        ToolbarPanel.resize(30, 600)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(ToolbarPanel.sizePolicy().hasHeightForWidth())
        ToolbarPanel.setSizePolicy(sizePolicy)
        ToolbarPanel.setMinimumSize(QtCore.QSize(30, 337))
        ToolbarPanel.setMaximumSize(QtCore.QSize(30, 600))
        ToolbarPanel.setBaseSize(QtCore.QSize(30, 403))
        ToolbarPanel.setWindowTitle("guiscrcpy")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        ToolbarPanel.setWindowIcon(icon)
        ToolbarPanel.setWindowOpacity(1.0)
        ToolbarPanel.setStyleSheet("QDialog{\n"
"width: 30px\n"
"}\n"
"QPushButton {\n"
"                        \n"
"\n"
"border-radius: 1px;\n"
"        background-color: qlineargradient(spread:pad, x1:0, y1:0.915182, x2:0, y2:0.926, stop:0.897059 rgba(41, 41, 41, 255), stop:1 rgba(30, 30, 30, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        \n"
"                    }\n"
"\n"
"QPushButton:pressed {\n"
"border-radius: 5px;\n"
"                      \n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"QPushButton:hover {\n"
"border-radius: 5px;\n"
"                      \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"")
        self.layoutWidget = QtWidgets.QWidget(ToolbarPanel)
        self.layoutWidget.setGeometry(QtCore.QRect(0, 0, 33, 601))
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.screenfreeze = QtWidgets.QPushButton(self.layoutWidget)
        self.screenfreeze.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.screenfreeze.sizePolicy().hasHeightForWidth())
        self.screenfreeze.setSizePolicy(sizePolicy)
        self.screenfreeze.setMouseTracking(True)
        self.screenfreeze.setTabletTracking(True)
        self.screenfreeze.setAutoFillBackground(False)
        self.screenfreeze.setStyleSheet("")
        self.screenfreeze.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/cross-mark-on-a-black-circle-background.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.screenfreeze.setIcon(icon1)
        self.screenfreeze.setFlat(True)
        self.screenfreeze.setObjectName("screenfreeze")
        self.verticalLayout.addWidget(self.screenfreeze)
        self.fullscreenUI = QtWidgets.QPushButton(self.layoutWidget)
        self.fullscreenUI.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fullscreenUI.sizePolicy().hasHeightForWidth())
        self.fullscreenUI.setSizePolicy(sizePolicy)
        self.fullscreenUI.setMouseTracking(True)
        self.fullscreenUI.setTabletTracking(True)
        self.fullscreenUI.setAutoFillBackground(False)
        self.fullscreenUI.setStyleSheet("")
        self.fullscreenUI.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/increase-size-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.fullscreenUI.setIcon(icon2)
        self.fullscreenUI.setFlat(True)
        self.fullscreenUI.setObjectName("fullscreenUI")
        self.verticalLayout.addWidget(self.fullscreenUI)
        self.notif_pull = QtWidgets.QPushButton(self.layoutWidget)
        self.notif_pull.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notif_pull.sizePolicy().hasHeightForWidth())
        self.notif_pull.setSizePolicy(sizePolicy)
        self.notif_pull.setMouseTracking(True)
        self.notif_pull.setTabletTracking(True)
        self.notif_pull.setAutoFillBackground(False)
        self.notif_pull.setStyleSheet("")
        self.notif_pull.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/bell-musical-tool.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.notif_pull.setIcon(icon3)
        self.notif_pull.setFlat(True)
        self.notif_pull.setObjectName("notif_pull")
        self.verticalLayout.addWidget(self.notif_pull)
        self.notif_collapse = QtWidgets.QPushButton(self.layoutWidget)
        self.notif_collapse.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notif_collapse.sizePolicy().hasHeightForWidth())
        self.notif_collapse.setSizePolicy(sizePolicy)
        self.notif_collapse.setMouseTracking(True)
        self.notif_collapse.setTabletTracking(True)
        self.notif_collapse.setAutoFillBackground(False)
        self.notif_collapse.setStyleSheet("")
        self.notif_collapse.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/icons/bell-musical-tool(2).svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.notif_collapse.setIcon(icon4)
        self.notif_collapse.setFlat(True)
        self.notif_collapse.setObjectName("notif_collapse")
        self.verticalLayout.addWidget(self.notif_collapse)
        self.clipD2PC = QtWidgets.QPushButton(self.layoutWidget)
        self.clipD2PC.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.clipD2PC.sizePolicy().hasHeightForWidth())
        self.clipD2PC.setSizePolicy(sizePolicy)
        self.clipD2PC.setMouseTracking(True)
        self.clipD2PC.setTabletTracking(True)
        self.clipD2PC.setAutoFillBackground(False)
        self.clipD2PC.setStyleSheet("")
        self.clipD2PC.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/icons/copy-document.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.clipD2PC.setIcon(icon5)
        self.clipD2PC.setFlat(True)
        self.clipD2PC.setObjectName("clipD2PC")
        self.verticalLayout.addWidget(self.clipD2PC)
        self.clipPC2D = QtWidgets.QPushButton(self.layoutWidget)
        self.clipPC2D.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.clipPC2D.sizePolicy().hasHeightForWidth())
        self.clipPC2D.setSizePolicy(sizePolicy)
        self.clipPC2D.setMouseTracking(True)
        self.clipPC2D.setTabletTracking(True)
        self.clipPC2D.setAutoFillBackground(False)
        self.clipPC2D.setStyleSheet("")
        self.clipPC2D.setText("")
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/icons/copy-document(1).svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.clipPC2D.setIcon(icon6)
        self.clipPC2D.setFlat(True)
        self.clipPC2D.setObjectName("clipPC2D")
        self.verticalLayout.addWidget(self.clipPC2D)
        self.vup = QtWidgets.QPushButton(self.layoutWidget)
        self.vup.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.vup.sizePolicy().hasHeightForWidth())
        self.vup.setSizePolicy(sizePolicy)
        self.vup.setMouseTracking(True)
        self.vup.setTabletTracking(True)
        self.vup.setAutoFillBackground(False)
        self.vup.setStyleSheet("")
        self.vup.setText("")
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/icons/volume-up-interface-symbol.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.vup.setIcon(icon7)
        self.vup.setFlat(True)
        self.vup.setObjectName("vup")
        self.verticalLayout.addWidget(self.vup)
        self.vdown = QtWidgets.QPushButton(self.layoutWidget)
        self.vdown.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.vdown.sizePolicy().hasHeightForWidth())
        self.vdown.setSizePolicy(sizePolicy)
        self.vdown.setMouseTracking(True)
        self.vdown.setTabletTracking(True)
        self.vdown.setAutoFillBackground(False)
        self.vdown.setStyleSheet("")
        self.vdown.setText("")
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/icons/reduced-volume.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.vdown.setIcon(icon8)
        self.vdown.setFlat(True)
        self.vdown.setObjectName("vdown")
        self.verticalLayout.addWidget(self.vdown)
        self.powerUI = QtWidgets.QPushButton(self.layoutWidget)
        self.powerUI.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.powerUI.sizePolicy().hasHeightForWidth())
        self.powerUI.setSizePolicy(sizePolicy)
        self.powerUI.setMouseTracking(True)
        self.powerUI.setTabletTracking(True)
        self.powerUI.setAutoFillBackground(False)
        self.powerUI.setStyleSheet("")
        self.powerUI.setText("")
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/icons/power.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.powerUI.setIcon(icon9)
        self.powerUI.setIconSize(QtCore.QSize(16, 16))
        self.powerUI.setCheckable(False)
        self.powerUI.setFlat(True)
        self.powerUI.setObjectName("powerUI")
        self.verticalLayout.addWidget(self.powerUI)
        self.home = QtWidgets.QPushButton(self.layoutWidget)
        self.home.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.home.sizePolicy().hasHeightForWidth())
        self.home.setSizePolicy(sizePolicy)
        self.home.setMouseTracking(True)
        self.home.setTabletTracking(True)
        self.home.setAutoFillBackground(False)
        self.home.setStyleSheet("")
        self.home.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/icons/home.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.home.setIcon(icon10)
        self.home.setFlat(True)
        self.home.setObjectName("home")
        self.verticalLayout.addWidget(self.home)
        self.back = QtWidgets.QPushButton(self.layoutWidget)
        self.back.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.back.sizePolicy().hasHeightForWidth())
        self.back.setSizePolicy(sizePolicy)
        self.back.setMouseTracking(True)
        self.back.setTabletTracking(True)
        self.back.setAutoFillBackground(False)
        self.back.setStyleSheet("")
        self.back.setText("")
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/icons/chevron-sign-left.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.back.setIcon(icon11)
        self.back.setFlat(True)
        self.back.setObjectName("back")
        self.verticalLayout.addWidget(self.back)
        self.menuUI = QtWidgets.QPushButton(self.layoutWidget)
        self.menuUI.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.menuUI.sizePolicy().hasHeightForWidth())
        self.menuUI.setSizePolicy(sizePolicy)
        self.menuUI.setMouseTracking(True)
        self.menuUI.setTabletTracking(True)
        self.menuUI.setAutoFillBackground(False)
        self.menuUI.setStyleSheet("")
        self.menuUI.setText("")
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icons/icons/reorder-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuUI.setIcon(icon12)
        self.menuUI.setFlat(True)
        self.menuUI.setObjectName("menuUI")
        self.verticalLayout.addWidget(self.menuUI)
        self.appswi = QtWidgets.QPushButton(self.layoutWidget)
        self.appswi.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.appswi.sizePolicy().hasHeightForWidth())
        self.appswi.setSizePolicy(sizePolicy)
        self.appswi.setMouseTracking(True)
        self.appswi.setTabletTracking(True)
        self.appswi.setAutoFillBackground(False)
        self.appswi.setStyleSheet("")
        self.appswi.setText("")
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icons/icons/four-black-squares.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.appswi.setIcon(icon13)
        self.appswi.setFlat(True)
        self.appswi.setObjectName("appswi")
        self.verticalLayout.addWidget(self.appswi)
        self.pinchinUI = QtWidgets.QPushButton(self.layoutWidget)
        self.pinchinUI.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pinchinUI.sizePolicy().hasHeightForWidth())
        self.pinchinUI.setSizePolicy(sizePolicy)
        self.pinchinUI.setStyleSheet("")
        self.pinchinUI.setText("")
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icons/icons/zoom-in.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pinchinUI.setIcon(icon14)
        self.pinchinUI.setFlat(True)
        self.pinchinUI.setObjectName("pinchinUI")
        self.verticalLayout.addWidget(self.pinchinUI)
        self.pinchoutUI = QtWidgets.QPushButton(self.layoutWidget)
        self.pinchoutUI.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pinchoutUI.sizePolicy().hasHeightForWidth())
        self.pinchoutUI.setSizePolicy(sizePolicy)
        self.pinchoutUI.setStyleSheet("")
        self.pinchoutUI.setText("")
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icons/icons/zoom-out.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pinchoutUI.setIcon(icon15)
        self.pinchoutUI.setFlat(True)
        self.pinchoutUI.setObjectName("pinchoutUI")
        self.verticalLayout.addWidget(self.pinchoutUI)
        self.potraitUI = QtWidgets.QPushButton(self.layoutWidget)
        self.potraitUI.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.potraitUI.sizePolicy().hasHeightForWidth())
        self.potraitUI.setSizePolicy(sizePolicy)
        self.potraitUI.setToolTipDuration(2)
        self.potraitUI.setStyleSheet("")
        self.potraitUI.setText("")
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icons/icons/vertical-resizing-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.potraitUI.setIcon(icon16)
        self.potraitUI.setFlat(True)
        self.potraitUI.setObjectName("potraitUI")
        self.verticalLayout.addWidget(self.potraitUI)
        self.landscapeUI = QtWidgets.QPushButton(self.layoutWidget)
        self.landscapeUI.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.landscapeUI.sizePolicy().hasHeightForWidth())
        self.landscapeUI.setSizePolicy(sizePolicy)
        self.landscapeUI.setToolTipDuration(2)
        self.landscapeUI.setStyleSheet("")
        self.landscapeUI.setText("")
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/icons/horizontal-resize-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.landscapeUI.setIcon(icon17)
        self.landscapeUI.setFlat(True)
        self.landscapeUI.setObjectName("landscapeUI")
        self.verticalLayout.addWidget(self.landscapeUI)
        self.tk_device_id = QtWidgets.QPushButton(self.layoutWidget)
        self.tk_device_id.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tk_device_id.sizePolicy().hasHeightForWidth())
        self.tk_device_id.setSizePolicy(sizePolicy)
        self.tk_device_id.setMinimumSize(QtCore.QSize(0, 2))
        self.tk_device_id.setMaximumSize(QtCore.QSize(16777215, 20))
        self.tk_device_id.setToolTipDuration(2)
        self.tk_device_id.setStyleSheet("")
        self.tk_device_id.setText("")
        self.tk_device_id.setFlat(True)
        self.tk_device_id.setObjectName("tk_device_id")
        self.verticalLayout.addWidget(self.tk_device_id)
        self.label_2 = QtWidgets.QLabel(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setScaledContents(True)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.label = QtWidgets.QLabel(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setScaledContents(True)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)

        self.retranslateUi(ToolbarPanel)
        QtCore.QMetaObject.connectSlotsByName(ToolbarPanel)

    def retranslateUi(self, ToolbarPanel):
        _translate = QtCore.QCoreApplication.translate
        self.fullscreenUI.setToolTip(_translate("ToolbarPanel", "Fullscreen"))
        self.notif_pull.setToolTip(_translate("ToolbarPanel", "Expand notification panel"))
        self.notif_collapse.setToolTip(_translate("ToolbarPanel", "Expand notification panel"))
        self.clipD2PC.setToolTip(_translate("ToolbarPanel", "Copy device clipbioard to PC"))
        self.clipPC2D.setToolTip(_translate("ToolbarPanel", "Copy PC clipboard to Device"))
        self.vup.setToolTip(_translate("ToolbarPanel", "Volume Up"))
        self.powerUI.setToolTip(_translate("ToolbarPanel", "Power on/off"))
        self.home.setToolTip(_translate("ToolbarPanel", "Home key"))
        self.back.setToolTip(_translate("ToolbarPanel", "Back key"))
        self.menuUI.setToolTip(_translate("ToolbarPanel", "Menu key"))
        self.appswi.setToolTip(_translate("ToolbarPanel", "press the APP_SWITCH button"))
        self.pinchinUI.setToolTip(_translate("ToolbarPanel", "Pinch in the screen"))
        self.pinchoutUI.setToolTip(_translate("ToolbarPanel", "Pinch out in the screen"))
        self.potraitUI.setToolTip(_translate("ToolbarPanel", "Potrait"))
        self.landscapeUI.setToolTip(_translate("ToolbarPanel", "Landscape"))
        self.tk_device_id.setToolTip(_translate("ToolbarPanel", "Landscape"))
        self.label_2.setText(_translate("ToolbarPanel", "...."))
        self.label.setText(_translate("ToolbarPanel", "::::"))
from . import rsrc_rc



import os
from subprocess import PIPE

from .base import Bridge
from ...lib.utils import shellify as _, open_process


class ScrcpyBridge(Bridge):
    name = "scrcpy"

    def post_init(self):
        if os.getenv("SCRCPY_LDD"):
            if os.getenv("LD_LIBRARY_PATH"):
                os.environ["LD_LIBRARY_PATH"] += os.getenv("SCRCPY_LDD")
            else:
                os.environ["LD_LIBRARY_PATH"] = os.getenv("SCRCPY_LDD")

    def start(self, args, stdout=PIPE, stderr=PIPE):
        proc = open_process(
            _("{} {}".format(self.path, args)),
            stdout=stdout,
            stderr=stderr,
        )
        return proc



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import logging
import os
import shlex
import shutil
import sys
import subprocess

from qtpy.QtGui import QPixmap
from colorama import Fore
from qtpy import QtCore
from qtpy.QtWidgets import QMessageBox
from ..platform.platform import System

environment = System()

COLORS = {
    "g": Fore.GREEN,
    "rst": Fore.RESET,
    "y": Fore.YELLOW,
    "r": Fore.RED,
    "b": Fore.BLUE,
    "B": Fore.LIGHTBLUE_EX,
    "x": Fore.LIGHTBLACK_EX,
}


def log(*args, **kwargs):
    if os.getenv("GUISCRCPY_DEBUG", False):
        print(*args, **kwargs)
    else:
        logging.debug(str(args))


def shellify(args):
    if environment.system() == "Windows":
        return args
    else:
        return shlex.split(args)


_ = shellify


def decode_process(process):
    try:
        output = process.stdout.readlines()
        for i in range(len(output)):
            output[i] = output[i].decode("utf-8")
    except NameError:
        logging.error("No stdout in process.")
        output = ""
    return output


def check_existence(paths, filename="", directory=True, path=False):
    for i in paths:
        j = os.path.expanduser(i)
        if os.path.exists(j):  # directory exists
            if directory and os.path.isdir(j):
                return [j]
            else:
                if environment.system() == "Windows":
                    append = ".exe"
                else:
                    append = ""

                if (isinstance(filename, list)) or (isinstance(filename, tuple)):
                    for exe in filename:
                        if os.path.exists(os.path.join(j, exe + append)):
                            return [os.path.join(j, exe + append)]
                else:

                    if os.path.exists(os.path.join(j, filename + append)):
                        return [os.path.join(j, filename + append)]
        else:
            logging.debug("{} doesn't exist".format(i))

    if path:
        new_paths = os.getenv("PATH").split(os.pathsep)
        found_path = check_existence(
            new_paths, filename=filename, directory=directory, path=False
        )
        if found_path:
            return found_path + ["path"]
        else:
            return False
    else:
        return False


def get_self():
    """
    Returns the path to the running executable depending on the conditions
    :return:
    :rtype:
    """
    if os.getenv("APPIMAGE"):
        # Running from AppImage
        return os.getenv("APPIMAGE")
    elif getattr(sys, "frozen", False):
        # running in precompiled bundle
        return sys.executable
    elif shutil.which("guiscrcpy"):
        # guiscrcpy is added to PATH
        return shutil.which("guiscrcpy")
    elif any([os.path.exists(os.path.join(x, "guiscrcpy")) for x in sys.path]) and any(
        [sys.executable.endswith(py) for py in ["python", "python3"]]
    ):
        # guiscrcpy is installed as a pip package, but not added to PATH
        return "{py} -m guiscrcpy".format(py=sys.executable)
    elif os.getenv("SNAP"):
        # running from SNAP
        return "/snap/bin/guiscrcpy"
    raise RuntimeError(
        "Could not detect if guiscrcpy was run from " "snap, appimage or python wheel"
    )


def format_colors(string, **kwargs):
    return string.format(**kwargs, **COLORS)


def show_message_box(text, info_text="", buttons=QMessageBox.Ok):
    """
    Shows a message box
    :param text:
    :param info_text:
    :param buttons:
    :return:
    """
    message_box = QMessageBox()
    try:
        message_box.setIconPixmap(
            QPixmap(":/res/ui/guiscrcpy_logo.png").scaledToHeight(100)
        )
    except Exception as e:
        print(
            "WARN: {e}: loading guiscrcpy "
            "message box pixmap failed. "
            "Ignoring".format(e=e)
        )
    message_box.setText("<b>{}</b>".format(text))
    message_box.setTextFormat(QtCore.Qt.RichText)
    message_box.setInformativeText(info_text)
    message_box.setStandardButtons(buttons)
    return message_box


def open_process(*args, **kwargs):
    if (
        environment.system() == "Windows"
        and sys.version_info.major >= 3
        and sys.version_info.minor >= 7
    ):
        return subprocess.Popen(
            *args,
            **kwargs,
            creationflags=subprocess.CREATE_NO_WINDOW,
        )
    else:
        return subprocess.Popen(*args, **kwargs)



import sys
import subprocess


from .base import AudioBridge
from ...utils import shellify as _, open_process


class USBAudioBridge(AudioBridge):
    name = "usbaudio"

    def run(self, device_id=None):
        if device_id is None:
            command = "{usbaudio}"
        else:
            command = "{usbaudio} --serial {device_id}"
        open_process(
            _(command.format(usbaudio=self.get_path(), device_id=device_id)),
            stdout=sys.stdout,
            stderr=sys.stderr,
        )



import logging
import socket
import threading
import time


class NetworkManager:
    @staticmethod
    def get_my_ip():
        """
        Find my IP address
        :return:
        """
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(("8.8.8.8", 80))
        ip = s.getsockname()[0]
        s.close()
        return ip

    def map_network(self, pool_size=255):
        """
        Maps the network
        :param pool_size: amount of parallel ping processes
        :return: list of valid ip addresses
        """
        ip_list = list()

        # get my IP and compose a base like 192.168.1.xxx
        ip_parts = self.get_my_ip().split(".")
        base_ip = ip_parts[0] + "." + ip_parts[1] + "." + ip_parts[2] + "."

        max_threads = 50

        def check_adb_port(ip):
            """
            Check if port is open
            :param ip:
            :param port:
            :return:
            """
            try:
                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                socket.setdefaulttimeout(2.0)
                result = sock.connect_ex((ip, 5555))
                if result == 0:
                    ip_list.append(ip)
                sock.close()
            except Exception as e:
                logging.warning("Unable to check %s: %s", ip, e)

        for i in range(1, 255):
            threading.Thread(
                target=check_adb_port,
                args=[f"{base_ip}{i}"],
            ).start()

        # limit the number of threads.
        while threading.active_count() > max_threads:
            time.sleep(1)

        return ip_list


if __name__ == "__main__":
    print("Mapping...")
    nm = NetworkManager()
    lst = nm.map_network()
    print(lst)



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
import hashlib
import logging
import os
import shlex
import shutil
import subprocess
import sys

from guiscrcpy.platform.platform import System

if System.system() == "Windows":
    try:
        import pyautogui as auto
        from pygetwindow import getWindowsWithTitle
    except ModuleNotFoundError as e:
        logging.debug("pygetwindow, pyautogui " "failed with error code {}".format(e))
        auto = None
        getWindowsWithTitle = None
else:
    auto = None
    getWindowsWithTitle = None


def wmctrl_xdotool_linux_send_key(key):
    assert isinstance(key, str)
    assert System.system() == "Linux"
    wmctrl = shutil.which("wmctrl")
    xdotool = shutil.which("xdotool")
    if not wmctrl or not xdotool:
        print(
            "E: Could not find {} on PATH. Make sure "
            "that a compatible package is installed "
            "on your system for this function"
        )
        return
    _proc = subprocess.Popen(
        shlex.split("wmctrl -x -a scrcpy"), stdout=sys.stdout, stderr=sys.stderr
    )
    if _proc.wait() == 0:
        _xdotool_proc = subprocess.Popen(
            shlex.split(
                "xdotool key --clearmodifiers {}+{}".format(
                    os.getenv("GUISCRCPY_MODIFIER") or "alt", key
                )
            ),
            stdout=sys.stdout,
            stderr=sys.stderr,
        )
        if _xdotool_proc.wait() != 0:
            print("E (xdotool): Failed to send key {} to " "scrcpy window.".format(key))
    else:
        print("E (wmctrl): Failed to get scrcpy window. " "(Is scrcpy running?)")


class UXMapper:
    def __init__(self, adb, device_id=None, sha_shift=5):
        """
        The main class for UXMapper and adb shell spawn to device
        The guiscrcpy client passes information ot the UXMapper which
        spawns adb sub processes to handle button and tap events
        :param device_id:
        """
        self.adb = adb
        self.sha_shift = sha_shift
        logging.debug("Launching UX Mapper")
        self.has_modules = getWindowsWithTitle and auto
        logging.debug("Calculating Screen Size")
        self.android_dimensions = adb.get_dimensions(device_id=device_id)
        if not self.android_dimensions:
            print(
                "E: guiscrcpy has crashed because of a failure in the "
                "execution of `adb shell wm size`. This might be because "
                "of an improper connection of adb. Please reconnect your "
                "device (disconnect from WiFi / Reconnect USB) or try \n\n"
                "guiscrcpy --killserver\n\nas a command line to restart adb "
                "server"
            )
        self.deviceId = device_id

        # each device connected is uniquely identified by the tools by
        # a salted hash. The toolkits are assigned colors based on the first
        # 6 colors and the stylesheet is derived from
        self.__sha = hashlib.sha256(str(self.deviceId).encode()).hexdigest()

    def get_sha(self):
        """
        A method which returns the unique UUID of the the device
        :return: The hexdigest of a salted hash
        """
        return self.__sha[self.sha_shift : self.sha_shift + 6]

    def do_swipe(self, x1=10, y1=10, x2=10, y2=10):
        """
        Performs a basic swipe operation
        :param x1: x1 coordinate
        :param y1: y1 coordinate
        :param x2: x2 coordinate
        :param y2: y2 coordinate
        :return: Boolean True, in success
        """
        self.adb.shell_input(
            "swipe {} {} {} {}".format(x1, y1, x2, y2), device_id=self.deviceId
        )
        return True

    def do_keyevent(self, key):
        """
        Performs a key event on adb
        :param key: The ADB predefined keycode
        :return:
        """
        self.adb.shell_input("keyevent {}".format(key), device_id=self.deviceId)
        return True

    def copy_devpc(self):
        if self.has_modules:
            scrcpywindow = getWindowsWithTitle("scrcpy")[0]
            scrcpywindow.focus()
            auto.hotkey("alt", "c")
        else:
            wmctrl_xdotool_linux_send_key("c")

    def key_power(self):
        logging.debug("Passing POWER")
        self.do_keyevent(26)

    def key_menu(self):
        logging.debug("Passing MENU")
        self.do_keyevent(82)

    def key_back(self):
        logging.debug("Passing BACK")
        self.do_keyevent(4)

    def key_volume_up(self):
        logging.debug("Passing BACK")
        self.do_keyevent(24)

    def key_volume_down(self):
        logging.debug("Passing BACK")
        self.do_keyevent(25)

    def key_home(self):
        logging.debug("Passing HOME")
        self.do_keyevent(3)

    def key_switch(self):
        logging.debug("Passing APP_SWITCH")
        self.do_keyevent("KEYCODE_APP_SWITCH")

    def reorient_portrait(self):
        logging.debug("Passing REORIENT [POTRAIT]")
        self.adb.shell(
            "settings put system accelerometer_rotation 0", device_id=self.deviceId
        )
        self.adb.shell("settings put system rotation 1", device_id=self.deviceId)

    def reorient_landscape(self):
        logging.debug("Passing REORIENT [LANDSCAPE]")
        self.adb.shell(
            "settings put system accelerometer_rotation 0", device_id=self.deviceId
        )
        self.adb.shell("settings put system rotation 1", device_id=self.deviceId)

    def expand_notifications(self):
        logging.debug("Passing NOTIF EXPAND")
        self.do_swipe(0, 0, 0, int(self.android_dimensions[1]) - 1)

    def collapse_notifications(self):
        logging.debug("Passing NOTIF COLLAPSE")
        self.do_swipe(0, int(self.android_dimensions[1]) - 1, 0, 0)

    def copy_pc2dev(self):
        if self.has_modules:
            scrcpywindow = getWindowsWithTitle("scrcpy")[0]
            scrcpywindow.focus()
            auto.hotkey("alt", "shift", "c")
        else:
            wmctrl_xdotool_linux_send_key("shift+c")

    def fullscreen(self):
        if self.has_modules:
            scrcpy_window = getWindowsWithTitle("scrcpy")[0]
            scrcpy_window.focus()
            auto.hotkey("alt", "f")
        else:
            wmctrl_xdotool_linux_send_key("f")



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
import platform
import shutil
import uuid

from qtpy import QtCore
from qtpy.QtCore import QPoint
from qtpy.QtWidgets import QMainWindow

from ..lib.toolkit import UXMapper
from ..ux import Ui_ToolbarPanel


class InterfaceToolkit(QMainWindow, Ui_ToolbarPanel):
    def __init__(self, ux_mapper=None, parent=None, frame=False, always_on_top=True):
        """
        Side panel toolkit for guiscrcpy main window
        :param ux_mapper:
        :param parent:
        :param frame:
        :param: always_on_top: bool
        """
        QMainWindow.__init__(self)
        Ui_ToolbarPanel.__init__(self)
        self.name = "toolkit"
        self.uid = uuid.uuid4()
        self.setupUi(self)
        self.parent = parent
        self.oldPos = None
        self.ux = None
        __flags = QtCore.Qt.Window
        if not frame:
            __flags |= QtCore.Qt.FramelessWindowHint
        if always_on_top:
            __flags |= QtCore.Qt.WindowStaysOnTopHint
        self.setWindowFlags(__flags)
        if ux_mapper:
            self.ux = ux_mapper
        else:
            self.ux = UXMapper()

    def init(self):
        if platform.system() != "Linux" or (
            shutil.which("wmctrl")
            and shutil.which("xdotool")
            and platform.system() == "Linux"
        ):
            self.clipD2PC.clicked.connect(self.ux.copy_devpc)
            self.clipPC2D.clicked.connect(self.ux.copy_pc2dev)
            self.fullscreenUI.clicked.connect(self.ux.fullscreen)
        else:
            # the tools do not exist on Linux. user has to manually install
            for button, helper in (
                (self.clipD2PC, "Alt + C"),
                (self.clipPC2D, "Alt + Shift + C"),
                (self.fullscreenUI, "Alt + F"),
            ):
                button.setDisabled(True)
                button.setToolTip(
                    'This function is disabled because "wmctrl"'
                    ' or "xdotool" is not found on your installation.'
                    "Keyboard shortcut can be used instead"
                    ": <b>{}</b>".format(helper)
                )

        self.back.clicked.connect(self.ux.key_back)
        self.screenfreeze.clicked.connect(self.quit_window)
        self.appswi.clicked.connect(self.ux.key_switch)
        self.menuUI.clicked.connect(self.ux.key_menu)
        self.home.clicked.connect(self.ux.key_home)
        self.notif_pull.clicked.connect(self.ux.expand_notifications)
        self.notif_collapse.clicked.connect(self.ux.collapse_notifications)
        self.powerUI.clicked.connect(self.ux.key_power)
        self.vup.clicked.connect(self.ux.key_volume_up)
        self.vdown.clicked.connect(self.ux.key_volume_down)
        self.potraitUI.clicked.connect(self.ux.reorient_portrait)
        self.landscapeUI.clicked.connect(self.ux.reorient_landscape)
        self.colorize()  # give a unique color for each device
        self.show()

    def colorize(self):
        hexdigest = self.ux.get_sha()[:6]
        self.tk_device_id.setStyleSheet(f"background-color: #{hexdigest};")

    def mousePressEvent(self, event):
        self.oldPos = event.globalPos()

    def mouseMoveEvent(self, event):
        try:
            delta = QPoint(event.globalPos() - self.oldPos)
            self.move(self.x() + delta.x(), self.y() + delta.y())
            self.oldPos = event.globalPos()
        except (TypeError, AttributeError):
            pass

    def quit_window(self):
        for instance in self.parent.child_windows:  # noqa
            # We are checking for any more windows running before killing
            # the main window. self.child_windows has the list of all
            # objects spawned by the main window ui
            # This method checks if we are the last member of the windows
            # spawned and we ourselves are not a member of ourself by
            # checking the uuid generated on creation
            if (
                not instance.isHidden()
                and instance.name != "swipe"
                and instance.uid != self.uid
            ):
                self.hide()
                break
        else:
            for instance in self.parent.child_windows:  # noqa
                if (
                    instance.name == "swipe"
                    and instance.ux.get_sha() == self.ux.get_sha()
                ):
                    instance.hide()
            self.hide()



import os
import platform
import sys
import traceback

import click
import colorama
from click import Context
from qtpy.QtWidgets import QApplication
from qtpy import QtCore, QtWidgets

from .lib.utils import format_colors as fc, show_message_box
from .launcher import bootstrap
from .lib.bridge.exceptions import ScrcpyNotFoundError
from .lib.bridge.exceptions import AdbNotFoundError
from .lib.bridge.exceptions import ScrcpyServerNotFoundError
from .lib.bridge import AndroidDebugBridge
from .lib.config import InterfaceConfig, InvalidConfigurationError
from .version import VERSION
from . import __doc__ as lic


# initialize colorama on Windows systems
colorama.init()


# srevin: bad snap!
_sys_argv = list()
for arg in sys.argv:
    if not arg.startswith("/snap"):
        _sys_argv.append(arg)
sys.argv = _sys_argv


def show_version(ctx, param, value):  # noqa:
    """Prints the version of the utility"""
    if not value or ctx.resilient_parsing:
        return
    click.echo(fc("{g}guiscrcpy {rst}v{v}", v=VERSION))
    if os.getenv("APPIMAGE"):
        click.echo("Running from AppImage")
    if os.getenv("APPDIR"):
        click.echo("AppDir: {}".format(os.getenv("APPDIR")))
    import inspect
    from PyQt5 import Qt

    _pyqt5_version = [
        "%s = %s" % (k, v)
        for k, v in vars(Qt).items()
        if k.lower().find("version") >= 0 and not inspect.isbuiltin(v)
    ]
    print()
    print("== PyQt5 Version ==")
    print("\n".join(sorted(_pyqt5_version)))
    print()
    if platform.system() == "Linux":
        print("== CairoSVG version ==")
        from cairosvg import VERSION as CAIRO_VERSION  # noqa:

        print("CairoSVG == {}".format(CAIRO_VERSION))
        print()

    ctx.exit()


def show_license(ctx, param, value):  # noqa:
    """Prints the license of the utility"""
    if not value or ctx.resilient_parsing:
        return
    click.echo(lic)
    ctx.exit()


@click.group(invoke_without_command=True)
@click.pass_context
@click.option(
    "--version", is_flag=True, callback=show_version, expose_value=False, is_eager=True
)
@click.option(
    "--license",
    "--lic",
    is_flag=True,
    callback=show_license,
    expose_value=False,
    is_eager=True,
)
@click.option(
    "-T",
    "--theme",
    "theme",
    default="Breeze",
    help="Set the default theme (based on PyQt5 "
    "themes - Fusion, Breeze, Windows) "
    "(stored in configuration, override by --theme-no-cfg)",
)
@click.option(
    "-W",
    "--hide-wm-frame/--show-wm-frame",
    "hide_wm_frame",
    default=True,
    help="Show window manager border frame.",
)
@click.option(
    "--debug-disable-scrcpy",
    "debug_disable_scrcpy",
    default=False,
    is_flag=True,
    help="Do not launch scrcpy even when 'Start Scrcpy' is pressed",
)
@click.option(
    "-A",
    "--always-on-top/--disable-always-on-top",
    "aot",
    default=True,
    help="Forces the panels to be always of top",
)
def cli(
    ctx: Context,
    hide_wm_frame: bool = True,
    aot: bool = True,
    theme: str = "Breeze",
    debug_disable_scrcpy: bool = False,
):
    """guiscrcpy: Graphical user interface for scrcpy"""
    print(fc("\n{b}guiscrcpy {v}{rst}", v=VERSION))
    print(fc("by @srevinsaju"))
    print(fc("{x}https://github.com/srevinsaju/guiscrcpy{rst}\n\n"))
    if ctx.invoked_subcommand is not None:
        return
    try:
        # why this try block?
        # this is because, in case guiscrcpy crashes,
        # it will log the traceback to the terminal
        # but it would not be visible to users without CLI interface
        # enable High DPI scaling

        if platform.system() == "Windows":
            import ctypes

            # why this code?
            # In Windows 7 or later, the taskbar is not for "Application" but for "Application User Model/AppUserModel"
            # pythonw.exe application is host process, it means all application run by pythonw.exe will use same AppUserModel as pythonw.exe
            # So that applications runs by pythonw.exe will use same taskbar
            # To avoid this we must set AppUserModel id explicity
            # see this
            # https://stackoverflow.com/a/1552105/9986755
            # thttp://msdn.microsoft.com/en-us/library/dd378459%28VS.85%29.aspx#host
            appid = "srevinsaju.guiscrcpy"
            ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(appid)

        QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
        # use HIGH DPI icons
        QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
        # init core
        app = QtWidgets.QApplication(sys.argv)
        config_manager = InterfaceConfig()
        bootstrap(
            app=app,
            config_manager=config_manager,
            theme=theme,
            aot=aot,
            hide_wm_frame=hide_wm_frame,
            debug_no_scrcpy=debug_disable_scrcpy,
        )
    except ScrcpyNotFoundError:
        _msg_box = show_message_box(
            text="Scrcpy not found",
            info_text="guiscrcpy could not find scrcpy. "
            "Make sure you select scrcpy in the dialog box "
            "or add scrcpy to PATH. You can get the latest release "
            "of scrcpy from <a href='"
            "https://github.com/Genymobile/scrcpy'>"
            "Genymobile/scrcpy 's GitHub Releases</a> "
            "and select the <pre>scrcpy{ext}</pre> when you run "
            "guiscrcpy next time".format(
                ext=".exe" if platform.system() == "Windows" else ""
            ),
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except AdbNotFoundError:
        _msg_box = show_message_box(
            text="ADB not found",
            info_text="guiscrcpy could not find adb. "
            "Make sure you select adb in the dialog box or add adb to PATH",
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except InvalidConfigurationError:
        _msg_box = show_message_box(
            text="Invalid configuration error",
            info_text="The configuration file for guiscrcpy is invalid. <br>"
            "This is possibly because a new version of guiscrcpy "
            "was installed, or the old paths to `adb` and `scrcpy` "
            "as defined in the configuration file, no longer exists "
            "in the same path. To fix this error,"
            "Run  "
            "<pre>guiscrcpy config -r</pre> on your terminal.",
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except ScrcpyServerNotFoundError:
        _msg_box = show_message_box(
            text="Scrcpy server not found error",
            info_text="The configuration file for guiscrcpy is invalid. <br>"
            "This is possibly because a new version of guiscrcpy "
            "was installed, or the old paths to `adb` and `scrcpy` "
            "as defined in the configuration file, no longer exists "
            "in the same path. To fix this error,"
            "Run  "
            "<pre>guiscrcpy config -r</pre> on your terminal.",
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except Exception:  # noqa:
        error_message = traceback.format_exc(chain=True)
        print(error_message)
        _msg_box = show_message_box(
            text="Error: Unhandled exception",
            info_text="<pre>{error_message}</pre>"
            "Please report this, if its a bug, to <a href="
            "'https://github.com/srevinsaju/guiscrcpy/issues'>"
            "guiscrcpy bug tracker</a> as it will help to improve "
            "the next release.".format(error_message=error_message),
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)


@cli.command()
@click.option(
    "--device-id",
    "device_id",
    help="Sets the device-id for mapper to configure "
    " (optional, needed for multiple devices)",
)
@click.option(
    "-r",
    "--reset",
    "reset",
    is_flag=True,
    help="Reset guiscrcpy's mapper configuration file",
)
def mapper(device_id=None, reset=False):
    """Run the guiscrcpy mapper"""
    config_manager = InterfaceConfig()
    config = config_manager.get_config()
    mapper_cfg_path = os.path.join(
        config_manager.get_cfgpath(), "guiscrcpy.mapper.json"
    )
    if reset:
        # A ternary version of removing a file if it exists
        # https://stackoverflow.com/q/10840533/
        mapper_configuration_file_exists = (
            os.remove(mapper_cfg_path) if os.path.exists(mapper_cfg_path) else None
        )
        if mapper_configuration_file_exists:
            print("guiscrcpy mapper configuration file has been removed.")
            print("Removed {}".format(mapper_configuration_file_exists))
        else:
            print("guiscrcpy mapper configuration is not created yet.")
        return

    if os.getenv("GUISCRCPY_ADB"):
        adb_path = os.getenv("GUISCRCPY_ADB")
    else:
        adb_path = config["adb"]
    adb = AndroidDebugBridge(adb_path)
    adb_devices_list = adb.devices()
    if len(adb_devices_list) == 0:
        print("E: No devices found")
        sys.exit(1)
    elif len(adb_devices_list) == 1:
        mapper_device_id = adb_devices_list[0][0]
    elif not device_id:
        print("Please pass the --device-id <device_id> to initialize " "the mapper")
        sys.exit(1)
    else:
        mapper_device_id = device_id

    from guiscrcpy.lib.mapper.mapper import Mapper

    # Initialize the mapper if it is called.
    adb = AndroidDebugBridge(path=config_manager.get_config().get("adb"))
    mp = Mapper(mapper_device_id, adb=adb, config_path=mapper_cfg_path)
    if not os.path.exists(
        os.path.join(config_manager.get_cfgpath(), "guiscrcpy.mapper.json")
    ):
        print("guiscrcpy.mapper.json does not exist. ")
        print("Initializing Mapper Configuration for the first time use.")
        mp.initialize(initialize_qt=True)
    else:
        mp.read_configuration()
        print("guiscrcpy.mapper.json found. Starting the mapper...")
        print("Your keyboard is being listened by guiscrcpy-mapper")
        print("pressing any key will trigger the position.")
        print()
        print("If you would like to register new keys, pass --mapper-reset")
        print("\nInitializing\n\n")
        mp.listen_keypress()
        print("Done!")


@cli.command("adb")
@click.argument("args", nargs=-1)
def adb_cli(args):
    """Create an interface with the Android Debugging bridge"""
    config_manager = InterfaceConfig()
    config = config_manager.get_config()
    if os.getenv("GUISCRCPY_ADB"):
        adb_path = os.getenv("GUISCRCPY_ADB")
    else:
        adb_path = config["adb"]
    print("Interfacing guiscrcpy-adb")
    os.system("{} {}".format(adb_path, " ".join(args)))
    pass


@cli.command()
@click.argument("args", nargs=-1)
def scrcpy(args):
    """Create an interface with scrcpy"""
    config_manager = InterfaceConfig()
    config = config_manager.get_config()
    if os.getenv("GUISCRCPY_SCRCPY"):
        scrcpy_path = os.getenv("GUISCRCPY_SCRCPY")
    else:
        scrcpy_path = config["scrcpy"]
    print("Interfacing guiscrcpy-scrcpy")
    os.system("{} {}".format(scrcpy_path, " ".join(args)))
    pass


@cli.command("config")
@click.option(
    "-r", "--reset", "reset", is_flag=True, help="Reset the configuration files"
)
def _config(reset=False):
    """View / Edit the configuration file"""
    config_manager = InterfaceConfig(load=False)
    if reset:
        config_manager.reset_config()
        click.echo("Configuration file resetted successfully.")
        sys.exit(0)
    config_manager.load_config()
    print(config_manager)


@cli.command()
def fast_init():
    """Init scrcpy before guiscrcpy"""
    cfgmgr = InterfaceConfig()
    print(cfgmgr)


if __name__ == "__main__":
    cli()



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import logging
import os


class Darwin:
    def __init__(self):
        logging.error(
            "MacOS is untested. " "guiscrcpy is trying to use Linux config on Mac"
        )

    def cfgpath(self):
        return self.make_config()

    @staticmethod
    def make_config():
        if os.getenv("XDG_CONFIG_HOME") is None:
            path = os.path.expanduser("~/.config/guiscrcpy/")
        else:
            path = os.getenv("XDG_CONFIG_HOME").split(":")[0] + "/guiscrcpy"
        if not os.path.exists(path):
            try:
                os.makedirs(path)
            except Exception as e:
                logging.error(
                    "Error creating configuration filename in dir {path}. "
                    "Error code:{e}".format(path=path, e=e)
                )
        return path

    @staticmethod
    def system():
        return "Darwin"

    def increment(self):
        pass

    @staticmethod
    def paths():
        return ["bin", "/usr/bin", "~/.local/bin", "~/bin", "/usr/local/bin"]

    @staticmethod
    def install_fonts():
        return True



"""
guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import json
import os
import shutil
from guiscrcpy.platform import platform


class InvalidConfigurationError(RuntimeError):
    pass


class InterfaceConfig:
    def __init__(self, load=True):
        """
        Manages guiscrcpy's configuration files
        """
        self.os = platform.System()
        self.cfgpath = self.os.cfgpath()
        self.paths = self.os.paths()
        self.config = {
            "version": 1,
            "paths": self.paths,
            "scrcpy": None,
            "adb": None,
            "panels": {"swipe": True, "bottom": True, "toolkit": True},
            "mapper": "",
            "sha_shift": 5,
            "scrcpy-server": None,
            "dimension": None,
            "swtouches": False,
            "bitrate": 8000,
            "fullscreen": False,
            "dispRO": False,
            "extra": "",
            "cmx": "",
            "device": {},
            "theme": "Breeze",
        }
        self.json_file = "guiscrcpy.json"
        if load:
            self.load_config()

    def load_config(self):
        self.check_file()
        self.validate()

    def validate(self):
        # check scrcpy and adb are not None, else replace it with original
        # values
        if os.getenv("APPIMAGE") is not None:
            # no need further configuration for adb, scrcpy and scrcpy_server
            self.config["adb"] = os.getenv("GUISCRCPY_ADB")
            self.config["scrcpy"] = os.getenv("GUISCRCPY_SCRCPY")
            return True
        if self.config["adb"] is None:
            adb_path = shutil.which("adb")
            self.config["adb"] = adb_path
        else:
            _adb_path = self.config["adb"]
            if not os.path.exists(_adb_path):
                raise InvalidConfigurationError(
                    "The configuration key 'adb' is "
                    "invalid. {} does not exist. "
                    "If you did not set it on purpose, "
                    "run `guiscrcpy config -r` to reset "
                    "the configuration".format(self.config["adb"])
                )
        if self.config["scrcpy"] is None:
            scrcpy_path = shutil.which("scrcpy")
            self.config["scrcpy"] = scrcpy_path
        else:
            _scrcpy_path = self.config["scrcpy"]
            if not os.path.exists(_scrcpy_path):
                raise InvalidConfigurationError(
                    "The configuration key 'scrcpy' is "
                    "invalid. {} does not exist. "
                    "If you did not set it on purpose, "
                    "run `guiscrcpy config -r` to reset "
                    "the configuration".format(self.config["scrcpy"])
                )
        if (self.config["scrcpy-server"] is not None) and (
            platform.System() == "Windows"
        ):
            os.environ["SCRCPY_SERVER_PATH"] = self.config["scrcpy-server"]
        return True

    def __setitem__(self, key, value):
        self.config[key] = value
        self.write_file()

    def __getitem__(self, item):
        return self.config.get(item)

    def get_config(self):
        return self.config

    def get_scrcpy(self):
        if self.config["scrcpy"] is not None:
            return self.config["scrcpy"]
        else:
            return None

    def get_adb(self):
        if self.config["adb"] is not None:
            return self.config["adb"]
        else:
            return None

    def get_cfgpath(self):
        return self.cfgpath

    def read_file(self):
        with open(os.path.join(self.cfgpath, self.json_file), "r") as f:
            config = json.load(f)
        self.update_config(config)

    def write_file(self):
        with open(os.path.join(self.cfgpath, self.json_file), "w") as f:
            json.dump(self.config, f, indent=4, sort_keys=True)

    def check_file(self):

        if not os.path.exists(self.cfgpath):
            os.makedirs(self.cfgpath)
        if not os.path.exists(os.path.join(self.cfgpath, self.json_file)):
            self.write_file()
        self.read_file()

    def update_config(self, new_conf):
        for i in new_conf:
            for j in self.config:
                if i == j:
                    self.config[i] = new_conf[i]

    def reset_config(self):
        os.remove(os.path.join(self.get_cfgpath(), self.json_file))
        return True

    def __repr__(self):
        return 'GuiscrcpyConfig({}, "{}")'.format(
            json.dumps(self.config, indent=4), self.cfgpath
        )



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""


def dark_stylesheet():
    # DarkStyleSheet

    style = """
    /* ------------------------------------------------------------------------

    Created by the qtsass compiler v0.1.1

    The definitions are in the "qdarkstyle.qss._styles.scss" module

    WARNING! All changes made in this filename will be lost!

--------------------------------------------------------------------------- */
/* QDarkStyleSheet -----------------------------------------------------------

This is the main style sheet, the palette has nine colors.

It is based on three selecting colors, three greyish (background) colors
plus three whitish (foreground) colors. Each set of widgets of the same
type have a header like this:

    ------------------
    GroupName --------
    ------------------

And each widget is separated with a header like this:

    QWidgetName ------

This makes more easy to find and change some css field. The basic
configuration is described bellow.

    BACKGROUND -----------

        Light   (unpressed)
        Normal  (border, disabled, pressed, checked, toolbars, menus)
        Dark    (background)

    FOREGROUND -----------

        Light   (texts/labels)
        Normal  (not used yet)
        Dark    (disabled texts)

    SELECTION ------------

        Light  (selection/hover/active)
        Normal (selected)
        Dark   (selected disabled)

If a stranger configuration is required because of a bugfix or anything
else, keep the comment on the line above so nobody changes it, including the
issue number.

*/
/*

See Qt documentation:

  - https://doc.qt.io/qt-5/stylesheet.html
  - https://doc.qt.io/qt-5/stylesheet-reference.html
  - https://doc.qt.io/qt-5/stylesheet-examples.html

--------------------------------------------------------------------------- */
/* QWidget ----------------------------------------------------------------

--------------------------------------------------------------------------- */
QWidget {
  background-color: #19232D;
  border: 0px solid #32414B;
  padding: 0px;
  color: #F0F0F0;
  selection-background-color: #1464A0;
  selection-color: #F0F0F0;
}

QWidget:disabled {
  background-color: #19232D;
  color: #787878;
  selection-background-color: #14506E;
  selection-color: #787878;
}

QWidget::item:selected {
  background-color: #1464A0;
}

QWidget::item:hover {
  background-color: #148CD2;
  color: #32414B;
}

/* QMainWindow ------------------------------------------------------------

This adjusts the splitter in the dock widget, not qsplitter
https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qmainwindow

--------------------------------------------------------------------------- */
QMainWindow::separator {
  background-color: #32414B;
  border: 0px solid #19232D;
  spacing: 0px;
  padding: 2px;
}

QMainWindow::separator:hover {
  background-color: #505F69;
  border: 0px solid #148CD2;
}


/* QToolTip ---------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtooltip

--------------------------------------------------------------------------- */
QToolTip {
  background-color: #148CD2;
  border: 1px solid #19232D;
  color: #19232D;
  /* Remove padding, for fix combo box tooltip */
  padding: 0px;
  /* Remove opacity, fix #174 - may need to use RGBA */
}

/* QStatusBar -------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qstatusbar

--------------------------------------------------------------------------- */
QStatusBar {
  border: 1px solid #32414B;
  /* Fixes Spyder #9120, #9121 */
  background: #32414B;
}

QStatusBar QToolTip {
  background-color: #148CD2;
  border: 1px solid #19232D;
  color: #19232D;
  /* Remove padding, for fix combo box tooltip */
  padding: 0px;
  /* Reducing transparency to read better */
  opacity: 230;
}

QStatusBar QLabel {
  /* Fixes Spyder #9120, #9121 */
  background: transparent;
}

/* QCheckBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qcheckbox

--------------------------------------------------------------------------- */
QCheckBox {
  background-color: #19232D;
  color: #F0F0F0;
  spacing: 4px;
  outline: 4px;
  padding-top: 4px;
  padding-bottom: 4px;
  border-radius: 4px;
}

QCheckBox:focus {
  border: none;
}

QCheckBox QWidget:disabled {
  background-color: #19232D;
  color: #787878;
}



/* QGroupBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qgroupbox

--------------------------------------------------------------------------- */
QGroupBox {
  font-weight: bold;
  border: 1px solid #32414B;
  border-radius: 4px;
  padding: 4px;
  margin-top: 16px;
}

QGroupBox::title {
  subcontrol-origin: margin;
  subcontrol-position: top left;
  left: 3px;
  padding-left: 3px;
  padding-right: 5px;
  padding-top: 8px;
  padding-bottom: 16px;
}

QGroupBox::indicator {
  margin-left: 2px;
  height: 12px;
  width: 12px;
}


/* QRadioButton -----------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qradiobutton

--------------------------------------------------------------------------- */
QRadioButton {
  background-color: #19232D;
  color: #F0F0F0;
  spacing: 4px;
  padding: 0px;
  border: none;
  outline: none;
}

QRadioButton:focus {
  border: none;
}

QRadioButton:disabled {
  background-color: #19232D;
  color: #787878;
  border: none;
  outline: none;
}

QRadioButton QWidget {
  background-color: #19232D;
  color: #F0F0F0;
  spacing: 0px;
  padding: 0px;
  outline: none;
  border: none;
}

QRadioButton::indicator {
  border: none;
  outline: none;
  margin-left: 4px;
  height: 16px;
  width: 16px;
}

/* QMenuBar ---------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qmenubar

--------------------------------------------------------------------------- */
QMenuBar {
  background-color: #32414B;
  padding: 2px;
  border: 1px solid #19232D;
  color: #F0F0F0;
}

QMenuBar:focus {
  border: 1px solid #148CD2;
}

QMenuBar::item {
  background: transparent;
  padding: 4px;
}

QMenuBar::item:selected {
  padding: 4px;
  background: transparent;
  border: 0px solid #32414B;
}

QMenuBar::item:pressed {
  padding: 4px;
  border: 0px solid #32414B;
  background-color: #148CD2;
  color: #F0F0F0;
  margin-bottom: 0px;
  padding-bottom: 0px;
}

/* QMenu ------------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qmenu

--------------------------------------------------------------------------- */
QMenu {
  border: 0px solid #32414B;
  color: #F0F0F0;
  margin: 0px;
}

QMenu::separator {
  height: 1px;
  background-color: #505F69;
  color: #F0F0F0;
}

QMenu::icon {
  margin: 0px;
  padding-left: 4px;
}

QMenu::item {
  background-color: #32414B;
  padding: 4px 24px 4px 24px;
  /* Reserve space for selection border */
  border: 1px transparent #32414B;
}

QMenu::item:selected {
  color: #F0F0F0;
}

QMenu::indicator {
  width: 12px;
  height: 12px;
  padding-left: 6px;

}


/* QAbstractItemView ------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qcombobox

--------------------------------------------------------------------------- */
QAbstractItemView {
  alternate-background-color: #19232D;
  color: #F0F0F0;
  border: 1px solid #32414B;
  border-radius: 4px;
}

QAbstractItemView QLineEdit {
  padding: 2px;
}

/* QAbstractScrollArea ----------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qabstractscrollarea

--------------------------------------------------------------------------- */
QAbstractScrollArea {
  background-color: #19232D;
  border: 1px solid #32414B;
  border-radius: 4px;
  padding: 2px;
  /* fix #159 */
  min-height: 1.25em;
  /* fix #159 */
  color: #F0F0F0;
}

QAbstractScrollArea:disabled {
  color: #787878;
}

/* QScrollArea ------------------------------------------------------------

--------------------------------------------------------------------------- */
QScrollArea QWidget QWidget:disabled {
  background-color: #19232D;
}

/* QScrollBar -------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qscrollbar

--------------------------------------------------------------------------- */
QScrollBar:horizontal {
  height: 16px;
  margin: 2px 16px 2px 16px;
  border: 1px solid #32414B;
  border-radius: 4px;
  background-color: #19232D;
}

QScrollBar:vertical {
  background-color: #19232D;
  width: 16px;
  margin: 16px 2px 16px 2px;
  border: 1px solid #32414B;
  border-radius: 4px;
}

QScrollBar::handle:horizontal {
  background-color: #787878;
  border: 1px solid #32414B;
  border-radius: 4px;
  min-width: 8px;
}

QScrollBar::handle:horizontal:hover {
  background-color: #148CD2;
  border: 1px solid #148CD2;
  border-radius: 4px;
  min-width: 8px;
}

QScrollBar::handle:vertical {
  background-color: #787878;
  border: 1px solid #32414B;
  min-height: 8px;
  border-radius: 4px;
}

QScrollBar::handle:vertical:hover {
  background-color: #148CD2;
  border: 1px solid #148CD2;
  border-radius: 4px;
  min-height: 8px;
}

QScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal {
  background: none;
}

QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {
  background: none;
}

QScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal {
  background: none;
}

QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {
  background: none;
}

/* QTextEdit --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-specific-widgets

--------------------------------------------------------------------------- */
QTextEdit {
  background-color: #19232D;
  color: #F0F0F0;
  border-radius: 4px;
  border: 1px solid #32414B;
}

QTextEdit:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QTextEdit:selected {
  background: #1464A0;
  color: #32414B;
}

/* QPlainTextEdit ---------------------------------------------------------

--------------------------------------------------------------------------- */
QPlainTextEdit {
  background-color: #19232D;
  color: #F0F0F0;
  border-radius: 4px;
  border: 1px solid #32414B;
}

QPlainTextEdit:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QPlainTextEdit:selected {
  background: #1464A0;
  color: #32414B;
}

/* QSizeGrip --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qsizegrip

--------------------------------------------------------------------------- */

/* QStackedWidget ---------------------------------------------------------

--------------------------------------------------------------------------- */
QStackedWidget {
  padding: 2px;
  border: 1px solid #32414B;
  border: 1px solid #19232D;
}

/* QToolBar ---------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtoolbar

--------------------------------------------------------------------------- */
QToolBar {
  background-color: #32414B;
  border-bottom: 1px solid #19232D;
  padding: 2px;
  font-weight: bold;
  spacing: 2px;
}

QToolBar QToolButton {
  background-color: #32414B;
  border: 1px solid #32414B;
}

QToolBar QToolButton:hover {
  border: 1px solid #148CD2;
}

QToolBar QToolButton:checked {
  border: 1px solid #19232D;
  background-color: #19232D;
}

QToolBar QToolButton:checked:hover {
  border: 1px solid #148CD2;
}

/* QAbstractSpinBox -------------------------------------------------------

--------------------------------------------------------------------------- */
QAbstractSpinBox {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #F0F0F0;
  /* This fixes 103, 111 */
  padding-top: 2px;
  /* This fixes 103, 111 */
  padding-bottom: 2px;
  padding-left: 4px;
  padding-right: 4px;
  border-radius: 4px;
  /* min-width: 5px; removed to fix 109 */
}

QAbstractSpinBox:up-button {
  background-color: transparent #19232D;
  subcontrol-origin: border;
  subcontrol-position: top right;
  border-left: 1px solid #32414B;
  border-bottom: 1px solid #32414B;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin: 1px;
  width: 12px;
  margin-bottom: -1px;
}

QAbstractSpinBox:down-button {
  background-color: transparent #19232D;
  subcontrol-origin: border;
  subcontrol-position: bottom right;
  border-left: 1px solid #32414B;
  border-top: 1px solid #32414B;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  margin: 1px;
  width: 12px;
  margin-top: -1px;
}

QAbstractSpinBox:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QAbstractSpinBox:selected {
  background: #1464A0;
  color: #32414B;
}

/* ------------------------------------------------------------------------ */
/* DISPLAYS --------------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* QLabel -----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qframe

--------------------------------------------------------------------------- */
QLabel {
  background-color: #19232D;
  border: 0px solid #32414B;
  padding: 2px;
  margin: 0px;
  color: #F0F0F0;
}

QLabel::disabled {
  background-color: #19232D;
  border: 0px solid #32414B;
  color: #787878;
}

/* QTextBrowser -----------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qabstractscrollarea

--------------------------------------------------------------------------- */
QTextBrowser {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #F0F0F0;
  border-radius: 4px;
}

QTextBrowser:disabled {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #787878;
  border-radius: 4px;
}

QTextBrowser:hover, QTextBrowser:!hover,
QTextBrowser::selected, QTextBrowser::pressed {
  border: 1px solid #32414B;
}

/* QGraphicsView ----------------------------------------------------------

--------------------------------------------------------------------------- */
QGraphicsView {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #F0F0F0;
  border-radius: 4px;
}

QGraphicsView:disabled {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #787878;
  border-radius: 4px;
}

QGraphicsView:hover, QGraphicsView:!hover, QGraphicsView::selected,
QGraphicsView::pressed { border: 1px solid #32414B; }

/* QCalendarWidget --------------------------------------------------------

--------------------------------------------------------------------------- */
QCalendarWidget {
  border: 1px solid #32414B;
  border-radius: 4px;
}

QCalendarWidget:disabled {
  background-color: #19232D;
  color: #787878;
}

/* QLCDNumber -------------------------------------------------------------

--------------------------------------------------------------------------- */
QLCDNumber {
  background-color: #19232D;
  color: #F0F0F0;
}

QLCDNumber:disabled {
  background-color: #19232D;
  color: #787878;
}

/* QProgressBar -----------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qprogressbar

--------------------------------------------------------------------------- */
QProgressBar {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #F0F0F0;
  border-radius: 4px;
  text-align: center;
}

QProgressBar:disabled {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #787878;
  border-radius: 4px;
  text-align: center;
}

QProgressBar::chunk {
  background-color: #1464A0;
  color: #19232D;
  border-radius: 4px;
}

QProgressBar::chunk:disabled {
  background-color: #14506E;
  color: #787878;
  border-radius: 4px;
}

/* ------------------------------------------------------------------------ */
/* BUTTONS ---------------------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* QPushButton ------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qpushbutton

--------------------------------------------------------------------------- */
QPushButton {
  background-color: #505F69;
  border: 1px solid #32414B;
  color: #F0F0F0;
  border-radius: 4px;
  padding: 3px;
  outline: none;
}

QPushButton:disabled {
  background-color: #32414B;
  border: 1px solid #32414B;
  color: #787878;
  border-radius: 4px;
  padding: 3px;
}

QPushButton:checked {
  background-color: #32414B;
  border: 1px solid #32414B;
  border-radius: 4px;
  padding: 3px;
  outline: none;
}

QPushButton:checked:disabled {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #787878;
  border-radius: 4px;
  padding: 3px;
  outline: none;
}

QPushButton:checked:selected {
  background: #1464A0;
  color: #32414B;
}

QPushButton:checked:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QPushButton::menu-indicator {
  subcontrol-origin: padding;
  subcontrol-position: bottom right;
  bottom: 4px;
}

QPushButton:pressed {
  background-color: #19232D;
  border: 1px solid #19232D;
}

QPushButton:pressed:hover {
  border: 1px solid #148CD2;
}

QPushButton:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QPushButton:selected {
  background: #1464A0;
  color: #32414B;
}

/* QToolButton ------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtoolbutton

--------------------------------------------------------------------------- */
QToolButton {
  background-color: transparent;
  border: 1px solid transparent;
  border-radius: 4px;
  margin: 0px;
  padding: 2px;

}

QToolButton:checked {
  background-color: transparent;
  border: 1px solid #1464A0;
}

QToolButton:checked:disabled {
  border: 1px solid #14506E;
}

QToolButton:pressed {
  margin: 1px;
  background-color: transparent;
  border: 1px solid #1464A0;
}

QToolButton:disabled {
  border: none;
}

QToolButton:hover {
  border: 1px solid #148CD2;
}

QToolButton[popupMode="0"] {
  /* Only for DelayedPopup */
  padding-right: 2px;
}

QToolButton[popupMode="1"] {
  /* Only for MenuButtonPopup */
  padding-right: 20px;
}

QToolButton[popupMode="1"]::menu-button {
  border: none;
}

QToolButton[popupMode="1"]::menu-button:hover {
  border: none;
  border-left: 1px solid #148CD2;
  border-radius: 0;
}

QToolButton[popupMode="2"] {
  /* Only for InstantPopup */
  padding-right: 2px;
}

QToolButton::menu-button {
  padding: 2px;
  border-radius: 4px;
  border: 1px solid #32414B;
  width: 12px;
  outline: none;
}

QToolButton::menu-button:hover {
  border: 1px solid #148CD2;
}

QToolButton::menu-button:checked:hover {
  border: 1px solid #148CD2;
}

/* QCommandLinkButton -----------------------------------------------------

--------------------------------------------------------------------------- */
QCommandLinkButton {
  background-color: transparent;
  border: 1px solid #32414B;
  color: #F0F0F0;
  border-radius: 4px;
  padding: 0px;
  margin: 0px;
}

QCommandLinkButton:disabled {
  background-color: transparent;
  color: #787878;
}

/* ------------------------------------------------------------------------ */
/* INPUTS - NO FIELDS ----------------------------------------------------- */
/* ------------------------------------------------------------------------ */
/* QComboBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qcombobox

--------------------------------------------------------------------------- */
QComboBox {
  border: 1px solid #32414B;
  border-radius: 4px;
  selection-background-color: #1464A0;
  padding-left: 4px;
  padding-right: 4px;
  /* Fixes #103, #111 */
  min-height: 1.5em;
  /* padding-top: 2px;     removed to fix #132 */
  /* padding-bottom: 2px;  removed to fix #132 */
  /* min-width: 75px;      removed to fix #109 */
  /* Needed to remove indicator - fix #132 */
}

QComboBox QAbstractItemView {
  border: 1px solid #32414B;
  border-radius: 0;
  background-color: #19232D;
  selection-background-color: #1464A0;
}

QComboBox QAbstractItemView:hover {
  background-color: #19232D;
  color: #F0F0F0;
}

QComboBox QAbstractItemView:selected {
  background: #1464A0;
  color: #32414B;
}

QComboBox QAbstractItemView:alternate {
  background: #19232D;
}

QComboBox:disabled {
  background-color: #19232D;
  color: #787878;
}

QComboBox:hover {
  border: 1px solid #148CD2;
}

QComboBox:on {
  selection-background-color: #1464A0;
}

QComboBox::indicator {
  border: none;
  border-radius: 0;
  background-color: transparent;
  selection-background-color: transparent;
  color: transparent;
  selection-color: transparent;
  /* Needed to remove indicator - fix #132 */
}

QComboBox::indicator:alternate {
  background: #19232D;
}

QComboBox::item:alternate {
  background: #19232D;
}

QComboBox::item:checked {
  font-weight: bold;
}

QComboBox::item:selected {
  border: 0px solid transparent;
}

QComboBox::drop-down {
  subcontrol-origin: padding;
  subcontrol-position: top right;
  width: 12px;
  border-left: 1px solid #32414B;
}


/* QSlider ----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qslider

--------------------------------------------------------------------------- */
QSlider:disabled {
  background: #19232D;
}

QSlider:focus {
  border: none;
}

QSlider::groove:horizontal {
  background: #32414B;
  border: 1px solid #32414B;
  height: 4px;
  margin: 0px;
  border-radius: 4px;
}

QSlider::groove:vertical {
  background: #32414B;
  border: 1px solid #32414B;
  width: 4px;
  margin: 0px;
  border-radius: 4px;
}

QSlider::add-page:vertical {
  background: #1464A0;
  border: 1px solid #32414B;
  width: 4px;
  margin: 0px;
  border-radius: 4px;
}

QSlider::add-page:vertical :disabled {
  background: #14506E;
}

QSlider::sub-page:horizontal {
  background: #1464A0;
  border: 1px solid #32414B;
  height: 4px;
  margin: 0px;
  border-radius: 4px;
}

QSlider::sub-page:horizontal:disabled {
  background: #14506E;
}

QSlider::handle:horizontal {
  background: #787878;
  border: 1px solid #32414B;
  width: 8px;
  height: 8px;
  margin: -8px 0px;
  border-radius: 4px;
}

QSlider::handle:horizontal:hover {
  background: #148CD2;
  border: 1px solid #148CD2;
}

QSlider::handle:vertical {
  background: #787878;
  border: 1px solid #32414B;
  width: 8px;
  height: 8px;
  margin: 0 -8px;
  border-radius: 4px;
}

QSlider::handle:vertical:hover {
  background: #148CD2;
  border: 1px solid #148CD2;
}

/* QLineEdit --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qlineedit

--------------------------------------------------------------------------- */
QLineEdit {
  background-color: #19232D;
  padding-top: 2px;
  /* This QLineEdit fix  103, 111 */
  padding-bottom: 2px;
  /* This QLineEdit fix  103, 111 */
  padding-left: 4px;
  padding-right: 4px;
  border-style: solid;
  border: 1px solid #32414B;
  border-radius: 4px;
  color: #F0F0F0;
}

QLineEdit:disabled {
  background-color: #19232D;
  color: #787878;
}

QLineEdit:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QLineEdit:selected {
  background: #1464A0;
  color: #32414B;
}

/* QTabWiget --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtabwidget-and-qtabbar

--------------------------------------------------------------------------- */
QTabWidget {
  padding: 2px;
  selection-background-color: #32414B;
}

QTabWidget QWidget {
  /* Fixes #189 */
  border-radius: 4px;
}

QTabWidget::pane {
  border: 1px solid #32414B;
  border-radius: 4px;
  margin: 0px;
  /* Fixes double border inside pane with pyqt5 */
  padding: 0px;
}

QTabWidget::pane:selected {
  background-color: #32414B;
  border: 1px solid #1464A0;
}

/* QTabBar ----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtabwidget-and-qtabbar

--------------------------------------------------------------------------- */
QTabBar {
  qproperty-drawBase: 0;
  border-radius: 4px;
  margin: 0px;
  padding: 2px;
  border: 0;
  /* left: 5px; move to the right by 5px - removed for fix */
}

/* QTabBar::tab - selected ------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtabwidget-and-qtabbar

--------------------------------------------------------------------------- */
QTabBar::tab {
  /* !selected and disabled ----------------------------------------- */
  /* selected ------------------------------------------------------- */
}

QTabBar::tab:top:selected:disabled {
  border-bottom: 3px solid #14506E;
  color: #787878;
  background-color: #32414B;
}

QTabBar::tab:bottom:selected:disabled {
  border-top: 3px solid #14506E;
  color: #787878;
  background-color: #32414B;
}

QTabBar::tab:left:selected:disabled {
  border-right: 3px solid #14506E;
  color: #787878;
  background-color: #32414B;
}

QTabBar::tab:right:selected:disabled {
  border-left: 3px solid #14506E;
  color: #787878;
  background-color: #32414B;
}

QTabBar::tab:top:!selected:disabled {
  border-bottom: 3px solid #19232D;
  color: #787878;
  background-color: #19232D;
}

QTabBar::tab:bottom:!selected:disabled {
  border-top: 3px solid #19232D;
  color: #787878;
  background-color: #19232D;
}

QTabBar::tab:left:!selected:disabled {
  border-right: 3px solid #19232D;
  color: #787878;
  background-color: #19232D;
}

QTabBar::tab:right:!selected:disabled {
  border-left: 3px solid #19232D;
  color: #787878;
  background-color: #19232D;
}

QTabBar::tab:top:!selected {
  border-bottom: 2px solid #19232D;
  margin-top: 2px;
}

QTabBar::tab:bottom:!selected {
  border-top: 2px solid #19232D;
  margin-bottom: 3px;
}

QTabBar::tab:left:!selected {
  border-left: 2px solid #19232D;
  margin-right: 2px;
}

QTabBar::tab:right:!selected {
  border-right: 2px solid #19232D;
  margin-left: 2px;
}

QTabBar::tab:top {
  background-color: #32414B;
  color: #F0F0F0;
  margin-left: 2px;
  padding-left: 4px;
  padding-right: 4px;
  padding-top: 2px;
  padding-bottom: 2px;
  min-width: 5px;
  border-bottom: 3px solid #32414B;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

QTabBar::tab:top:selected {
  background-color: #505F69;
  color: #F0F0F0;
  border-bottom: 3px solid #1464A0;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

QTabBar::tab:top:!selected:hover {
  border: 1px solid #148CD2;
  border-bottom: 3px solid #148CD2;
  padding: 0px;
}

QTabBar::tab:bottom {
  color: #F0F0F0;
  border-top: 3px solid #32414B;
  background-color: #32414B;
  margin-left: 2px;
  padding-left: 4px;
  padding-right: 4px;
  padding-top: 2px;
  padding-bottom: 2px;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  min-width: 5px;
}

QTabBar::tab:bottom:selected {
  color: #F0F0F0;
  background-color: #505F69;
  border-top: 3px solid #1464A0;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
}

QTabBar::tab:bottom:!selected:hover {
  border: 1px solid #148CD2;
  border-top: 3px solid #148CD2;
  padding: 0px;
}

QTabBar::tab:left {
  color: #F0F0F0;
  background-color: #32414B;
  margin-top: 2px;
  padding-left: 2px;
  padding-right: 2px;
  padding-top: 4px;
  padding-bottom: 4px;
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
  min-height: 5px;
}

QTabBar::tab:left:selected {
  color: #F0F0F0;
  background-color: #505F69;
  border-right: 3px solid #1464A0;
}

QTabBar::tab:left:!selected:hover {
  border: 1px solid #148CD2;
  border-right: 3px solid #148CD2;
  padding: 0px;
}

QTabBar::tab:right {
  color: #F0F0F0;
  background-color: #32414B;
  margin-top: 2px;
  padding-left: 2px;
  padding-right: 2px;
  padding-top: 4px;
  padding-bottom: 4px;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  min-height: 5px;
}

QTabBar::tab:right:selected {
  color: #F0F0F0;
  background-color: #505F69;
  border-left: 3px solid #1464A0;
}

QTabBar::tab:right:!selected:hover {
  border: 1px solid #148CD2;
  border-left: 3px solid #148CD2;
  padding: 0px;
}

QTabBar QToolButton {
  /* Fixes #136 */
  background-color: #32414B;
  height: 12px;
  width: 12px;
}

QTabBar QToolButton:pressed {
  background-color: #32414B;
}

QTabBar QToolButton:pressed:hover {
  border: 1px solid #148CD2;
}

/* QDockWiget -------------------------------------------------------------

--------------------------------------------------------------------------- */


QDockWidget::title {
  /* Better size for title bar */
  padding: 6px;
  spacing: 4px;
  border: none;
  background-color: #32414B;
}

QDockWidget::close-button {
  background-color: #32414B;
  border-radius: 4px;
  border: none;
}

QDockWidget::float-button {
  background-color: #32414B;
  border-radius: 4px;
  border: none;
}

/* QTreeView QListView QTableView -----------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtreeview
https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qlistview
https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtableview

--------------------------------------------------------------------------- */


QTreeView,
QListView,
QTableView,
QColumnView {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #F0F0F0;
  gridline-color: #32414B;
  border-radius: 4px;
}

QTreeView:disabled,
QListView:disabled,
QTableView:disabled,
QColumnView:disabled {
  background-color: #19232D;
  color: #787878;
}

QTreeView:selected,
QListView:selected,
QTableView:selected,
QColumnView:selected {
  background: #1464A0;
  color: #32414B;
}

QTreeView::hover,
QListView::hover,
QTableView::hover,
QColumnView::hover {
  background-color: #19232D;
  border: 1px solid #148CD2;
}

QTreeView::item:pressed,
QListView::item:pressed,
QTableView::item:pressed,
QColumnView::item:pressed {
  background-color: #1464A0;
}

QTreeView::item:selected:hover,
QListView::item:selected:hover,
QTableView::item:selected:hover,
QColumnView::item:selected:hover {
  background: #1464A0;
  color: #19232D;
}

QTreeView::item:selected:active,
QListView::item:selected:active,
QTableView::item:selected:active,
QColumnView::item:selected:active {
  background-color: #1464A0;
}

QTreeView::item:!selected:hover,
QListView::item:!selected:hover,
QTableView::item:!selected:hover,
QColumnView::item:!selected:hover {
  outline: 0;
  color: #148CD2;
  background-color: #32414B;
}

QTableCornerButton::section {
  background-color: #19232D;
  border: 1px transparent #32414B;
  border-radius: 0px;
}

/* QHeaderView ------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qheaderview

--------------------------------------------------------------------------- */
QHeaderView {
  background-color: #32414B;
  border: 0px transparent #32414B;
  padding: 0px;
  margin: 0px;
  border-radius: 0px;
}

QHeaderView:disabled {
  background-color: #32414B;
  border: 1px transparent #32414B;
  padding: 2px;
}

QHeaderView::section {
  background-color: #32414B;
  color: #F0F0F0;
  padding: 2px;
  border-radius: 0px;
  text-align: left;
}

QHeaderView::section:checked {
  color: #F0F0F0;
  background-color: #1464A0;
}

QHeaderView::section:checked:disabled {
  color: #787878;
  background-color: #14506E;
}

QHeaderView::section::horizontal {
  padding-left: 4px;
  padding-right: 4px;
  border-left: 1px solid #19232D;
}

QHeaderView::section::horizontal::first,
QHeaderView::section::horizontal::only-one {
  border-left: 1px solid #32414B;
}

QHeaderView::section::horizontal:disabled {
  color: #787878;
}

QHeaderView::section::vertical {
  padding-left: 4px;
  padding-right: 4px;
  border-top: 1px solid #19232D;
}

QHeaderView::section::vertical::first,
QHeaderView::section::vertical::only-one {
  border-top: 1px solid #32414B;
}

QHeaderView::section::vertical:disabled {
  color: #787878;
}

/* QToolBox --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qtoolbox

--------------------------------------------------------------------------- */
QToolBox {
  padding: 0px;
  border: 0px;
  border: 1px solid #32414B;
}

QToolBox::selected {
  padding: 0px;
  border: 2px solid #1464A0;
}

QToolBox::tab {
  background-color: #19232D;
  border: 1px solid #32414B;
  color: #F0F0F0;
  border-top-left-radius: 4px;
  border-top-right-radius: 4px;
}

QToolBox::tab:disabled {
  color: #787878;
}

QToolBox::tab:selected {
  background-color: #505F69;
  border-bottom: 2px solid #1464A0;
}

QToolBox::tab:selected:disabled {
  background-color: #32414B;
  border-bottom: 2px solid #14506E;
}

QToolBox::tab:!selected {
  background-color: #32414B;
  border-bottom: 2px solid #32414B;
}

QToolBox::tab:!selected:disabled {
  background-color: #19232D;
}

QToolBox::tab:hover {
  border-color: #148CD2;
  border-bottom: 2px solid #148CD2;
}

QToolBox QScrollArea QWidget QWidget {
  padding: 0px;
  border: 0px;
  background-color: #19232D;
}

/* QFrame -----------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qframe
https://doc.qt.io/qt-5/qframe.html#-prop
https://doc.qt.io/qt-5/qframe.html#details
https://stackoverflow.com/questions/14581498/qt-stylesheet-for-hline-vline-color

--------------------------------------------------------------------------- */
/* (dot) .QFrame  fix #141, #126, #123 */
.QFrame {
  border-radius: 4px;
  border: 1px solid #32414B;
  /* No frame */
  /* HLine */
  /* HLine */
}

.QFrame[frameShape="0"] {
  border-radius: 4px;
  border: 1px transparent #32414B;
}

.QFrame[frameShape="4"] {
  max-height: 2px;
  border: none;
  background-color: #32414B;
}

.QFrame[frameShape="5"] {
  max-width: 2px;
  border: none;
  background-color: #32414B;
}

/* QSplitter --------------------------------------------------------------

https://doc.qt.io/qt-5/stylesheet-examples.html#customizing-qsplitter

--------------------------------------------------------------------------- */
QSplitter {
  background-color: #32414B;
  spacing: 0px;
  padding: 0px;
  margin: 0px;
}

QSplitter::separator {
  background-color: #32414B;
  border: 0px solid #19232D;
  spacing: 0px;
  padding: 1px;
  margin: 0px;
}

QSplitter::separator:hover {
  background-color: #787878;
}

/* QDateEdit --------------------------------------------------------------

--------------------------------------------------------------------------- */
QDateEdit {
  selection-background-color: #1464A0;
  border-style: solid;
  border: 1px solid #32414B;
  border-radius: 4px;
  /* This fixes 103, 111 */
  padding-top: 2px;
  /* This fixes 103, 111 */
  padding-bottom: 2px;
  padding-left: 4px;
  padding-right: 4px;
  min-width: 10px;
}

QDateEdit:on {
  selection-background-color: #1464A0;
}

QDateEdit::drop-down {
  subcontrol-origin: padding;
  subcontrol-position: top right;
  width: 12px;
  border-left: 1px solid #32414B;
}

QDateEdit QAbstractItemView {
  background-color: #19232D;
  border-radius: 4px;
  border: 1px solid #32414B;
  selection-background-color: #1464A0;
}

/* QAbstractView ----------------------------------------------------------

--------------------------------------------------------------------------- */
QAbstractView:hover {
  border: 1px solid #148CD2;
  color: #F0F0F0;
}

QAbstractView:selected {
  background: #1464A0;
  color: #32414B;
}

/* PlotWidget -------------------------------------------------------------

--------------------------------------------------------------------------- */
PlotWidget {
  /* Fix cut labels in plots #134 */
  padding: 0px;
}
    """
    return style



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import json
import os
import time
import uuid
import subprocess

from qtpy import QtWidgets
from qtpy.QtCore import QThread

from pynput import keyboard

from guiscrcpy.lib.bridge.exceptions import AdbRuntimeError
from guiscrcpy.lib.mapper.ux import MapperUI

fixed_pos = [0.0, 0.0]
final_pos = [0.0, 0.0]

json_file = "guiscrcpy.mapper.json"


def log(category, message):
    print("[{}]".format(str(category).upper()), message)


class Mapper:
    def __init__(self, device_id, adb, config_path=None):
        self.config = dict()
        self._device_id = device_id
        self.app = None
        self.adb = adb
        log("mapper", "Waiting for device...")
        self.adb.command("wait-for-any-device")
        log("mapper", "Device connection established...")
        self.window = None
        self.guiscrcpy_mapper_json = config_path
        self.dimensions = adb.get_dimensions(device_id)
        log("mapper", "Checking device orientation")
        if self.check_orientation() == 1:
            # reverse the detected dimensions.
            # possibly the device is landscape / not the default
            # orientation as detected by Android Window Manager
            self.dimensions = self.dimensions[::-1]

    def check_orientation(self):
        proc = self.adb.shell("dumpsys input")
        try:
            e_code = proc.wait(5)
        except subprocess.TimeoutExpired:
            e_code = 0
            log(
                "mapper",
                "Failed to detect orientation instantly. Expect"
                "invalid orientations.",
            )
        if e_code != 0:
            # process failed
            raise AdbRuntimeError(
                "adb failed with {ecode} when trying to "
                "execute command "
                "`adb shell dumpsys input`".format(ecode=e_code)
            )
        out, err = proc.communicate()
        out, err = out.decode(), err.decode()
        if "SurfaceOrientation" in out:
            # SurfaceOrientation gives the idea if the device is
            # landscape or portait. SurfaceOrientation: 1 mentions that
            # the mobile is oriented in the landscape orientation
            # SugrfaceOrientation: 0 indicates, default
            print("Detected SurfaceOrientation, processing...")
            if "SurfaceOrientation: 0" in out:
                print("Detected Portait orientation...")
                return 0
            elif "SurfaceOrientation: 1" in out:
                print("Detected Landscape orientation...")
                return 1
            else:
                print("Failed to detect orientation from device. " "Fallback to 0")
                return 0
        else:
            print(
                "Failed to detect Orientation. SurfaceOrientation" " key was not found"
            )
            return 0

    def set_device_id(self, device_id):
        """
        sets the internal device id to the :param
        :param device_id:
        :type device_id:
        :return:
        :rtype:
        """
        self._device_id = device_id

    def get_device_id(self):
        return self._device_id

    def get_screenshot(self):
        """
        Gets the screenshot using `adb screncap` command
        :return:
        :rtype:
        """
        print("Make sure your phone display is switched on.")
        uid = uuid.uuid4().hex  # generate a random seed
        print("Generating Screenshot: {}".format(uid))

        # capture screenshot using `adb screencap`
        print("Please wait. A full definition screenshot is being captured")

        adb_screencap_process = self.adb.command(
            "shell screencap -p /sdcard/{uid}.png".format(uid=uid),
            device_id=self._device_id,
        )
        adb_screencap_process_ecode = adb_screencap_process.wait(500)
        if adb_screencap_process_ecode != 0:
            print("Screenshot failed. Exiting")
            print(adb_screencap_process.stdout.read().decode("utf-8"))
            return
        # sleep for two seconds so that the image is processed
        time.sleep(2)

        # pull screenshot from android using `adb pull`
        adb_pull_process = self.adb.command(
            "pull /sdcard/{uid}.png {dest}".format(
                uid=uid, dest=os.path.dirname(self.guiscrcpy_mapper_json)
            ),
            device_id=self._device_id,
        )
        adb_pull_process_ecode = adb_pull_process.wait(500)

        if adb_pull_process_ecode != 0:
            print("Screenshot pull failed. Exiting")
            print(adb_pull_process.stdout.read().decode("utf-8"))
            return

        # sleep for 1 second to get capture time
        time.sleep(1)

        # remove data from user sdcard
        self.adb.command(
            "shell rm /sdcard/{uid}.png".format(uid=uid), device_id=self._device_id
        )
        print(
            "[LOG] Screenshot captured. Saved to {cfgpath}".format(
                cfgpath=os.path.dirname(self.guiscrcpy_mapper_json)
            )
        )
        return os.path.join(
            os.path.dirname(self.guiscrcpy_mapper_json), "{uid}.png".format(uid=uid)
        )

    # The following functions handle key events on the mapper
    def on_key_press(self, key):
        try:
            if key.char in self.config.keys():
                print("[KEY] Hotkey command executing")
                position_to_tap = self.config.get(key.char)
                c = self.adb.command(
                    "shell input tap {} {}".format(*position_to_tap),
                    device_id=self.get_device_id(),
                )
                print(c.stdout.read().decode("utf-8"))
                print("[KEY][COMPLETE]")

        except AttributeError:
            if key == keyboard.Key.shift:
                print("[KEY][MOD] Shift key")
            elif key == keyboard.Key.esc:
                print("[KEY][ESC] Aborting")
                return False
            else:
                print("[KEY][MOD] Special key {}".format(key))

    def listen_keypress(self):
        """
        Listens to keypress using pynput and executes self.on_key_press
        on every keydown
        :return:
        :rtype:
        """
        print("[SERVER] LISTENING VALUES:" "Your keys are being listened by server. ")
        try:
            with keyboard.Listener(on_press=self.on_key_press) as listener:
                listener.join()
        except KeyboardInterrupt:
            print("guiscrcpy-mapper aborted on user request")

    # configuration
    def read_configuration(self):
        if not os.path.exists(self.guiscrcpy_mapper_json):
            self.create_configuration()
        with open(self.guiscrcpy_mapper_json, "r", encoding="utf-8") as f:
            self.config.update(json.load(f))

    def create_configuration(self):
        with open(self.guiscrcpy_mapper_json, "w") as w:
            json.dump(self.config, w)
        print("Wrote configuration file.")

    def add_position(self, char, position):
        self.config[char] = position

    # initialize
    def initialize(self, initialize_qt=False):
        """
        Initializes GUI to set keys to mapper
        :return:
        :rtype:
        """
        print("Setting up guiscrcpy-mapper for the first time use...")
        print("Intializing GUI window")
        if __name__ == "__main__" or initialize_qt:
            print("Creating QtCore window Application instance")
            self.app = QtWidgets.QApplication([])
        self.window = MapperUI(
            self,
            self.get_screenshot(),
            self.dimensions,
            fixed_pos=fixed_pos,
            final_pos=final_pos,
        )
        self.app.processEvents()
        self.app.exec_()


class MapperAsync(QThread):
    def __init__(self, parent, device_id, adb, initialize=True, config_path=None):
        QThread.__init__(self, parent)
        self.parent = parent
        self.adb = adb
        self.device_id = device_id
        self.initialize = initialize
        self._config_path = config_path

    def run(self):
        mp = Mapper(self.device_id, adb=self.adb, config_path=self._config_path)
        if self.initialize:
            mp.initialize(initialize_qt=False)
        else:
            mp.read_configuration()
            mp.listen_keypress()



class ScrcpyNotFoundError(FileNotFoundError):
    pass


class ScrcpyServerNotFoundError(FileNotFoundError):
    pass


class AdbNotFoundError(FileNotFoundError):
    pass


class AdbRuntimeError(RuntimeError):
    pass



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import os

# flake8: noqa

__QT_INSTANCE = os.getenv("QT_API", False)

if __QT_INSTANCE and __QT_INSTANCE in ("pyside2", "pyqt5"):
    if __QT_INSTANCE == "pyside2":
        use_pyqt5 = False
    else:
        use_pyqt5 = True
else:
    # either QT_API is not defined or defined for an older version of PyQt5
    # just use PyQt5 as default
    use_pyqt5 = True

if use_pyqt5:
    from guiscrcpy.ui.pyqt5.main import Ui_MainWindow  # noqa: F401
    from guiscrcpy.ui.pyqt5.network import Ui_NetworkUI  # noqa: F401
    from guiscrcpy.ui.pyqt5.panel import Ui_HorizontalPanel  # noqa: F401
    from guiscrcpy.ui.pyqt5.settings import Ui_MainWindow as Ui_SettingsWindow
    from guiscrcpy.ui.pyqt5.downloader import Ui_Initializer  # noqa: F401
    from guiscrcpy.ui.pyqt5.toolkit import Ui_ToolbarPanel  # noqa: F401
else:
    from guiscrcpy.ui.pyside2.main import Ui_MainWindow  # noqa: F401
    from guiscrcpy.ui.pyside2.network import Ui_NetworkUI  # noqa: F401
    from guiscrcpy.ui.pyside2.panel import Ui_HorizontalPanel  # noqa: F401
    from guiscrcpy.ui.pyside2.settings import Ui_MainWindow as Ui_SettingsWindow
    from guiscrcpy.ui.pyside2.downloader import Ui_Initializer  # noqa: F401
    from guiscrcpy.ui.pyside2.toolkit import Ui_ToolbarPanel  # noqa: F401



import sys
import subprocess
import time

from .base import AudioBridge
from ...utils import shellify as _, show_message_box, open_process


class SndcpyBridge(AudioBridge):
    name = "sndcpy"

    def run(self, device_id=None):
        if device_id is None:
            command = "{sndcpy}"
        else:
            command = "{sndcpy} {device_id}"
        _proc = open_process(
            _(command.format(sndcpy=self.get_path(), device_id=device_id)),
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE,
            stdin=subprocess.PIPE,
        )
        waiting_since = 0
        while True:
            if waiting_since > 30:
                # we should stop now
                _out = show_message_box(
                    text="sndcpy Failed to connect",
                    info_text="We couldn't establish a proper connection "
                    "to your device. Check if sndcpy is given stream permissions. "
                    "See https://github.com/rom1v/sndcpy for more information.",
                )
                _out.exec_()
            line = _proc.stdout.readline()
            if not line:
                break
            if "Press Enter" in line.decode():
                _out = show_message_box(
                    text="Sndcpy",
                    info_text="Click Accept on your Android device, and then click 'ok'",
                )
                _out.exec_()
                _proc.stdin.write(b"\n\r\n\r")
                _proc.stdin.close()
                break
            time.sleep(0.1)
            waiting_since += 0.1



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from subprocess import PIPE

from ..lib.utils import shellify as _, open_process


def get(ls, idx, default=""):
    try:
        return ls[idx]
    except IndexError:
        return default


def _get_dimension_raw_noexcept(path, device_id=None):
    if device_id:
        shell_adb = open_process(
            _("{} -s {} shell wm size".format(path, device_id)),
            stdout=PIPE,
            stderr=PIPE,
        )
    else:
        shell_adb = open_process(
            _("{} shell wm size".format(path)), stdout=PIPE, stderr=PIPE
        )
    return shell_adb



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['guiscrcpy',
 'guiscrcpy.install',
 'guiscrcpy.lib',
 'guiscrcpy.lib.bridge',
 'guiscrcpy.lib.bridge.audio',
 'guiscrcpy.lib.mapper',
 'guiscrcpy.network',
 'guiscrcpy.platform',
 'guiscrcpy.platform.windows_tools',
 'guiscrcpy.settings',
 'guiscrcpy.theme',
 'guiscrcpy.ui',
 'guiscrcpy.ui.pyqt5',
 'guiscrcpy.ui.pyside2',
 'guiscrcpy.ux']

package_data = \
{'': ['*'],
 'guiscrcpy': ['ts/*'],
 'guiscrcpy.ui': ['fonts/*', 'icons/*', 'rsrc/*', 'ui/*']}

install_requires = \
['QtPy>=1.9.0,<2.0.0',
 'click>=8.0.1,<9.0.0',
 'colorama>=0.4.4,<0.5.0',
 'psutil>=5.8.0,<6.0.0',
 'pynput==1.6.8']

extras_require = \
{':platform_system == "Windows"': ['pywin32==302'],
 'PyInstaller': ['PyInstaller'],
 'PyQt5': ['PyQt5>=5.15.4,<6.0.0'],
 'PySide2': ['PySide2>=5.15.2,<6.0.0']}

entry_points = \
{'console_scripts': ['guiscrcpy = guiscrcpy.cli:cli']}

setup_kwargs = {
    'name': 'guiscrcpy',
    'version': '4.11.0',
    'description': 'A simple, pluggable, graphical user interface for the fastest Android screen mirroring software',
    'long_description': None,
    'author': 'Srevin Saju',
    'author_email': 'srevinsaju@sugarlabs.org',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<3.10',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/network.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_NetworkUI(object):
    def setupUi(self, NetworkUI):
        NetworkUI.setObjectName("NetworkUI")
        NetworkUI.setWindowModality(QtCore.Qt.ApplicationModal)
        NetworkUI.resize(374, 414)
        self.centralwidget = QtWidgets.QWidget(NetworkUI)
        self.centralwidget.setObjectName("centralwidget")
        self.layoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.layoutWidget.setGeometry(QtCore.QRect(2, 5, 371, 381))
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.listView = QtWidgets.QListWidget(self.layoutWidget)
        self.listView.setObjectName("listView")
        self.gridLayout.addWidget(self.listView, 0, 0, 1, 2)
        self.nm_refresh = QtWidgets.QPushButton(self.layoutWidget)
        self.nm_refresh.setObjectName("nm_refresh")
        self.gridLayout.addWidget(self.nm_refresh, 5, 0, 1, 1)
        self.tcpip = QtWidgets.QPushButton(self.layoutWidget)
        self.tcpip.setObjectName("tcpip")
        self.gridLayout.addWidget(self.tcpip, 4, 1, 1, 1)
        self.spinBox = QtWidgets.QSpinBox(self.layoutWidget)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.spinBox.setFont(font)
        self.spinBox.setToolTipDuration(2)
        self.spinBox.setMinimum(1000)
        self.spinBox.setMaximum(99999)
        self.spinBox.setProperty("value", 5555)
        self.spinBox.setObjectName("spinBox")
        self.gridLayout.addWidget(self.spinBox, 4, 0, 1, 1)
        self.nm_connect = QtWidgets.QPushButton(self.layoutWidget)
        self.nm_connect.setObjectName("nm_connect")
        self.gridLayout.addWidget(self.nm_connect, 5, 1, 1, 1)
        self.nm_det = QtWidgets.QPushButton(self.layoutWidget)
        self.nm_det.setEnabled(False)
        self.nm_det.setText("")
        self.nm_det.setObjectName("nm_det")
        self.gridLayout.addWidget(self.nm_det, 2, 0, 1, 2)
        self.lineEdit = QtWidgets.QLineEdit(self.layoutWidget)
        self.lineEdit.setObjectName("lineEdit")
        self.gridLayout.addWidget(self.lineEdit, 1, 0, 1, 2)
        self.verticalLayout.addLayout(self.gridLayout)
        NetworkUI.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(NetworkUI)
        self.statusbar.setObjectName("statusbar")
        NetworkUI.setStatusBar(self.statusbar)

        self.retranslateUi(NetworkUI)
        QtCore.QMetaObject.connectSlotsByName(NetworkUI)

    def retranslateUi(self, NetworkUI):
        _translate = QtCore.QCoreApplication.translate
        NetworkUI.setWindowTitle(_translate("NetworkUI", "Network Manager"))
        self.label.setText(_translate("NetworkUI", "List of Network Devices"))
        self.nm_refresh.setStatusTip(_translate("NetworkUI", "Refresh Devices list"))
        self.nm_refresh.setText(_translate("NetworkUI", "REFRESH"))
        self.tcpip.setText(_translate("NetworkUI", "TCPIP"))
        self.spinBox.setToolTip(_translate("NetworkUI", "Port number"))
        self.spinBox.setStatusTip(_translate("NetworkUI", "Port number"))
        self.nm_connect.setStatusTip(_translate("NetworkUI", "Establish connection"))
        self.nm_connect.setText(_translate("NetworkUI", "CONNECT"))
        self.lineEdit.setPlaceholderText(_translate("NetworkUI", "Cannot find your IP address? Enter it manually here"))



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'bottompanelui.ui'
##
## Created by: Qt User Interface Compiler version 5.15.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QDate, QDateTime, QMetaObject,
    QObject, QPoint, QRect, QSize, QTime, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QKeySequence, QLinearGradient, QPalette, QPainter,
    QPixmap, QRadialGradient)
from PySide2.QtWidgets import *

from  . import rsrc_rc

class Ui_HorizontalPanel(object):
    def setupUi(self, HorizontalPanel):
        if not HorizontalPanel.objectName():
            HorizontalPanel.setObjectName(u"HorizontalPanel")
        HorizontalPanel.resize(397, 24)
        icon = QIcon()
        icon.addFile(u":/res/ui/guiscrcpy_logo.png", QSize(), QIcon.Normal, QIcon.Off)
        HorizontalPanel.setWindowIcon(icon)
        HorizontalPanel.setStyleSheet(u"\n"
".QPushButton {\n"
"border-radius: 1px;\n"
"color: rgb(0, 0, 0);\n"
" \n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:0.915182, x2:0, y2:0.926, stop:0.897059 rgba(41, 41, 41, 255), stop:1 rgba(30, 30, 30, 255));\n"
"                    }\n"
"\n"
"QPushButton:pressed {\n"
"border-radius: 5px;\n"
"					  \n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"QPushButton:hover {\n"
"border-radius: 5px;\n"
"					  \n"
"	background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
"                        }\n"
"")
        self.backk = QPushButton(HorizontalPanel)
        self.backk.setObjectName(u"backk")
        self.backk.setEnabled(True)
        self.backk.setGeometry(QRect(230, 0, 51, 25))
        self.backk.setStyleSheet(u"")
        icon1 = QIcon()
        icon1.addFile(u":/icons/icons/chevron-sign-left.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.backk.setIcon(icon1)
        self.powerUII = QPushButton(HorizontalPanel)
        self.powerUII.setObjectName(u"powerUII")
        self.powerUII.setEnabled(True)
        self.powerUII.setGeometry(QRect(20, 0, 81, 25))
        self.powerUII.setStyleSheet(u"")
        icon2 = QIcon()
        icon2.addFile(u":/icons/icons/power.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.powerUII.setIcon(icon2)
        self.powerUII.setCheckable(False)
        self.menuUII = QPushButton(HorizontalPanel)
        self.menuUII.setObjectName(u"menuUII")
        self.menuUII.setEnabled(True)
        self.menuUII.setGeometry(QRect(110, 0, 51, 25))
        self.menuUII.setStyleSheet(u"")
        icon3 = QIcon()
        icon3.addFile(u":/icons/icons/reorder-option.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.menuUII.setIcon(icon3)
        self.vdownn = QPushButton(HorizontalPanel)
        self.vdownn.setObjectName(u"vdownn")
        self.vdownn.setEnabled(True)
        self.vdownn.setGeometry(QRect(290, 0, 31, 25))
        self.vdownn.setStyleSheet(u"")
        icon4 = QIcon()
        icon4.addFile(u":/icons/icons/reduced-volume.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.vdownn.setIcon(icon4)
        self.homee = QPushButton(HorizontalPanel)
        self.homee.setObjectName(u"homee")
        self.homee.setEnabled(True)
        self.homee.setGeometry(QRect(160, 0, 71, 25))
        self.homee.setStyleSheet(u"")
        icon5 = QIcon()
        icon5.addFile(u":/icons/icons/home.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.homee.setIcon(icon5)
        self.vupp = QPushButton(HorizontalPanel)
        self.vupp.setObjectName(u"vupp")
        self.vupp.setEnabled(True)
        self.vupp.setGeometry(QRect(320, 0, 31, 25))
        self.vupp.setStyleSheet(u"")
        icon6 = QIcon()
        icon6.addFile(u":/icons/icons/volume-up-interface-symbol.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.vupp.setIcon(icon6)
        self.label = QLabel(HorizontalPanel)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(0, -10, 20, 41))
        font = QFont()
        font.setFamily(u"Noto Sans")
        font.setPointSize(18)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setScaledContents(True)
        self.label.setAlignment(Qt.AlignCenter)
        self.bp_close = QPushButton(HorizontalPanel)
        self.bp_close.setObjectName(u"bp_close")
        self.bp_close.setEnabled(True)
        self.bp_close.setGeometry(QRect(350, 0, 31, 25))
        self.bp_close.setStyleSheet(u"")
        icon7 = QIcon()
        icon7.addFile(u":/icons/icons/cross-mark-on-a-black-circle-background.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.bp_close.setIcon(icon7)
        self.bp_device_id = QPushButton(HorizontalPanel)
        self.bp_device_id.setObjectName(u"bp_device_id")
        self.bp_device_id.setGeometry(QRect(380, 0, 20, 31))
        self.bp_device_id.setStyleSheet(u"")
        self.homee.raise_()
        self.backk.raise_()
        self.powerUII.raise_()
        self.menuUII.raise_()
        self.vdownn.raise_()
        self.vupp.raise_()
        self.label.raise_()
        self.bp_close.raise_()
        self.bp_device_id.raise_()

        self.retranslateUi(HorizontalPanel)

        QMetaObject.connectSlotsByName(HorizontalPanel)
    # setupUi

    def retranslateUi(self, HorizontalPanel):
        HorizontalPanel.setWindowTitle(QCoreApplication.translate("HorizontalPanel", u"guiscrcpy", None))
#if QT_CONFIG(tooltip)
        self.backk.setToolTip(QCoreApplication.translate("HorizontalPanel", u"Back key", None))
#endif // QT_CONFIG(tooltip)
        self.backk.setText("")
#if QT_CONFIG(tooltip)
        self.powerUII.setToolTip(QCoreApplication.translate("HorizontalPanel", u"Power on/off", None))
#endif // QT_CONFIG(tooltip)
        self.powerUII.setText("")
#if QT_CONFIG(tooltip)
        self.menuUII.setToolTip(QCoreApplication.translate("HorizontalPanel", u"Menu key", None))
#endif // QT_CONFIG(tooltip)
        self.menuUII.setText("")
#if QT_CONFIG(tooltip)
        self.vdownn.setToolTip(QCoreApplication.translate("HorizontalPanel", u"Volume Up", None))
#endif // QT_CONFIG(tooltip)
        self.vdownn.setText("")
#if QT_CONFIG(tooltip)
        self.homee.setToolTip(QCoreApplication.translate("HorizontalPanel", u"Home key", None))
#endif // QT_CONFIG(tooltip)
        self.homee.setText("")
        self.vupp.setText("")
        self.label.setText(QCoreApplication.translate("HorizontalPanel", u"::", None))
        self.bp_close.setText("")
        self.bp_device_id.setText("")
    # retranslateUi




from qtpy.QtWidgets import QFileDialog
from qtpy.QtCore import QDir


def open_exe_name_dialog(parent, appname):
    options = QFileDialog.Options()
    options |= QDir.AllEntries
    options |= QDir.Hidden

    file_dialog = QFileDialog()
    file_dialog.setFilter(QDir.AllEntries | QDir.Hidden)
    file_dialog.setFileMode(QFileDialog.ExistingFile)
    file_dialog.setWindowTitle(
        f"{appname} could not be found. Please locate in" "manually"
    )
    if file_dialog.exec():
        file_name = file_dialog.selectedFiles()
        print(file_name[0])
        return file_name[0]
    else:
        print("No file is selected. guiscrcpy is likely to fail")
